@@ -26,7 +26,7 @@ from apsg.feature import (
     EllipsoidSet as ellipsoidset,
     OrientationTensor2Set as ortensor2set,
     OrientationTensor3Set as ortensorset,
-    Cluster as cluster,
+    ClusterSet as cluster,
 )
 from apsg.feature import (
     DeformationGradient3 as defgrad,
@@ -98,6 +98,6 @@ __all__ = (
     "quicknet",
 )
 
-__version__ = "1.0.1"
+__version__ = "1.3.4"
 __author__ = "Ondrej Lexa"
 __email__ = "lexa.ondrej@gmail.com"
