@@ -21,6 +21,7 @@ apsg_conf = dict(
         grid_type="gss",
         grid_n=3000,
         tight_layout=False,
+        title_kws=dict(),
     ),
     stereonet_default_point_kwargs=dict(
         alpha=None,
@@ -57,27 +58,19 @@ apsg_conf = dict(
         color=None,
         ls="-",
         lw=1.5,
-        mec=None,
-        mew=1,
-        mfc=None,
-        ms=2,
     ),
     stereonet_default_arc_kwargs=dict(
         alpha=None,
         color=None,
         ls="-",
-        lw=1,
-        mec=None,
-        mew=1,
-        mfc=None,
-        ms=2,
+        lw=1.5,
     ),
     stereonet_default_scatter_kwargs=dict(
         alpha=None,
         s=None,
         c=None,
         linewidths=1.5,
-        marker=None,
+        marker="o",
         cmap=None,
         legend=False,
         num="auto",
@@ -87,20 +80,12 @@ apsg_conf = dict(
         color=None,
         ls="-",
         lw=1.5,
-        mec=None,
-        mew=1,
-        mfc=None,
-        ms=2,
     ),
     stereonet_default_pair_kwargs=dict(
         alpha=None,
         color=None,
         ls="-",
         lw=1.5,
-        mec=None,
-        mew=1,
-        mfc=None,
-        ms=4,
         line_marker="o",
     ),
     stereonet_default_fault_kwargs=dict(
@@ -108,10 +93,6 @@ apsg_conf = dict(
         color=None,
         ls="-",
         lw=1.5,
-        mec=None,
-        mew=1,
-        mfc=None,
-        ms=2,
     ),
     stereonet_default_hoeppner_kwargs=dict(
         alpha=None,
@@ -123,13 +104,23 @@ apsg_conf = dict(
         mew=1,
         ms=5,
     ),
-    stereonet_default_quiver_kwargs=dict(
+    stereonet_default_arrow_kwargs=dict(
         color=None,
         width=2,
         headwidth=5,
         pivot="mid",
         units="dots",
     ),
+    stereonet_default_tensor_kwargs=dict(
+        planes=True,
+        alpha=None,
+        color=None,
+        ls="-",
+        lw=1.5,
+        marker="o",
+        mew=1,
+        ms=9,
+    ),
     stereonet_default_contour_kwargs=dict(
         alpha=None,
         antialiased=True,
@@ -143,7 +134,7 @@ apsg_conf = dict(
         sigma=None,
         sigmanorm=True,
         show_data=False,
-        data_kwargs=dict(),
+        data_kws=dict(),
     ),
     roseplot_default_kwargs=dict(
         bins=36,
@@ -156,8 +147,9 @@ apsg_conf = dict(
         pdf_res=901,
         title=None,
         grid=True,
-        grid_kw=dict(),
+        grid_kws=dict(),
         tight_layout=False,
+        title_kws=dict(),
     ),
     roseplot_default_bar_kwargs=dict(
         alpha=None,
@@ -176,6 +168,7 @@ apsg_conf = dict(
         ls="-",
         lw=1.5,
         legend=False,
+        weight=1,
     ),
     roseplot_default_muci_kwargs=dict(
         confidence_level=95,
@@ -195,6 +188,7 @@ apsg_conf = dict(
         grid_style=":",
         title=None,
         tight_layout=False,
+        title_kws=dict(),
     ),
     fabricplot_default_point_kwargs=dict(
         alpha=None,
