@@ -8,12 +8,21 @@ import os
 from datetime import datetime
 import contextlib
 
-from apsg.feature._geodata import Lineation, Foliation, Pair, Fault
+from apsg.feature._geodata import Lineation, Foliation, Pair
 from apsg.feature._container import LineationSet, FoliationSet
 
 from sqlalchemy import create_engine, event
 from sqlalchemy.orm import sessionmaker
-from sqlalchemy import Column, Float, ForeignKey, Integer, String, Table, Text, text
+from sqlalchemy import (
+    Column,
+    Float,
+    ForeignKey,
+    Integer,
+    String,
+    Table,
+    Text,
+    text,
+)
 from sqlalchemy.orm import relationship
 from sqlalchemy.ext.declarative import declarative_base
 
@@ -24,24 +33,29 @@ metadata = Base.metadata
 class Meta(Base):
     __tablename__ = "meta"
 
-    id = Column(Integer, primary_key=True)
-    name = Column(String(16), nullable=False)
+    id = Column(Integer, primary_key=True, autoincrement=True)
+    name = Column(String(16), nullable=False, unique=True)
     value = Column(Text)
 
+    def __repr__(self):
+        return "Meta:{}={}".format(self.name, self.value)
+
 
 class Site(Base):
     __tablename__ = "sites"
 
-    id = Column(Integer, primary_key=True)
+    id = Column(Integer, primary_key=True, autoincrement=True)
     id_units = Column(ForeignKey("units.id"), nullable=False, index=True)
-    name = Column(String(16), nullable=False, server_default=text("''"))
+    name = Column(String(16), nullable=False, unique=True)
     x_coord = Column(Float, server_default=text("NULL"))
     y_coord = Column(Float, server_default=text("NULL"))
     description = Column(Text)
 
-    unit = relationship("Unit", back_populates="sites")
+    unit = relationship("Unit", back_populates="sites", cascade="save-update")
 
-    structdata = relationship("Structdata", back_populates="site")
+    structdata = relationship(
+        "Structdata", back_populates="site", cascade="all, delete-orphan"
+    )
 
     def __repr__(self):
         return "Site:{} ({})".format(self.name, self.unit.name)
@@ -50,16 +64,22 @@ class Site(Base):
 tagged = Table(
     "tagged",
     metadata,
-    Column("id", Integer, autoincrement=True),
-    Column("id_tags", Integer, ForeignKey("tags.id"), primary_key=True),
-    Column("id_structdata", Integer, ForeignKey("structdata.id"), primary_key=True),
+    Column("id", Integer, primary_key=True, autoincrement=True),
+    Column("id_tags", Integer, ForeignKey("tags.id"), nullable=False, index=True),
+    Column(
+        "id_structdata",
+        Integer,
+        ForeignKey("structdata.id"),
+        nullable=False,
+        index=True,
+    ),
 )
 
 
 class Attached(Base):
     __tablename__ = "attach"
 
-    id = Column(Integer, primary_key=True)
+    id = Column(Integer, primary_key=True, autoincrement=True)
     id_structdata_planar = Column(
         ForeignKey("structdata.id"), nullable=False, index=True
     )
@@ -74,7 +94,7 @@ class Attached(Base):
 class Structdata(Base):
     __tablename__ = "structdata"
 
-    id = Column(Integer, primary_key=True)
+    id = Column(Integer, primary_key=True, autoincrement=True)
     id_sites = Column(ForeignKey("sites.id"), nullable=False, index=True)
     id_structype = Column(ForeignKey("structype.id"), nullable=False, index=True)
     azimuth = Column(Float, nullable=False, server_default=text("0"))
@@ -82,9 +102,13 @@ class Structdata(Base):
     description = Column(Text)
 
     site = relationship("Site", back_populates="structdata")
-    structype = relationship("Structype", back_populates="structdata")
+    structype = relationship(
+        "Structype", back_populates="structdata", cascade="save-update"
+    )
 
-    tags = relationship("Tag", secondary=tagged, back_populates="structdata")
+    tags = relationship(
+        "Tag", secondary=tagged, back_populates="structdata", cascade="save-update"
+    )
 
     attach_planar = relationship(
         "Attached", backref="planar", primaryjoin=id == Attached.id_structdata_planar
@@ -102,9 +126,9 @@ class Structdata(Base):
 class Structype(Base):
     __tablename__ = "structype"
 
-    id = Column(Integer, primary_key=True)
+    id = Column(Integer, primary_key=True, autoincrement=True)
     pos = Column(Integer, nullable=False, server_default=text("0"))
-    structure = Column(String(16), nullable=False)
+    structure = Column(String(16), nullable=False, unique=True)
     description = Column(Text)
     structcode = Column(Integer, server_default=text("0"))
     groupcode = Column(Integer, server_default=text("0"))
@@ -119,9 +143,9 @@ class Structype(Base):
 class Tag(Base):
     __tablename__ = "tags"
 
-    id = Column(Integer, primary_key=True)
+    id = Column(Integer, primary_key=True, autoincrement=True)
     pos = Column(Integer, nullable=False, server_default=text("0"))
-    name = Column(String(16), nullable=False)
+    name = Column(String(16), nullable=False, unique=True)
     description = Column(Text)
 
     structdata = relationship("Structdata", secondary=tagged, back_populates="tags")
@@ -133,9 +157,9 @@ class Tag(Base):
 class Unit(Base):
     __tablename__ = "units"
 
-    id = Column(Integer, primary_key=True)
+    id = Column(Integer, primary_key=True, autoincrement=True)
     pos = Column(Integer, nullable=False, server_default=text("0"))
-    name = Column(String(60), nullable=False)
+    name = Column(String(60), nullable=False, unique=True)
     description = Column(Text)
 
     sites = relationship("Site", back_populates="unit")
@@ -144,17 +168,17 @@ class Unit(Base):
         return "Unit:{}".format(self.name)
 
 
-def initial_meta():
-    return [
-        Meta(name="version", value="3.0.4"),
-        Meta(name="crs", value="EPSG:4326"),
-        Meta(name="created", value=datetime.now().strftime("%d.%m.%Y %H:%M")),
-        Meta(name="updated", value=datetime.now().strftime("%d.%m.%Y %H:%M")),
-        Meta(name="accessed", value=datetime.now().strftime("%d.%m.%Y %H:%M")),
-    ]
+def default_meta():
+    return dict(
+        version="3.1.0",
+        crs="EPSG:4326",
+        created=datetime.now().strftime("%d.%m.%Y %H:%M"),
+        updated=datetime.now().strftime("%d.%m.%Y %H:%M"),
+        accessed=datetime.now().strftime("%d.%m.%Y %H:%M"),
+    )
 
 
-def initial_values():
+def default_initial_values():
     return [
         Structype(
             pos=1,
@@ -184,7 +208,8 @@ def before_commit_meta_update(session):
 def before_insert_pos_update(mapper, connection, target):
     if target.pos is None:
         t = str(mapper.persist_selectable)
-        maxpos = connection.execute("SELECT max({}.pos) FROM {}".format(t, t)).scalar()
+        query = "SELECT max({}.pos) FROM {}".format(t, t)
+        maxpos = connection.scalar(text(query))
         if maxpos is None:
             maxpos = 1
         else:
@@ -202,6 +227,8 @@ class SDBSession:
     Keyword Args:
         create (bool): if True existing sdbfile will be deleted
             and new database will be created
+        autocommit(bool): if True, each operation is autocommitted.
+            Default False
 
     Example:
         >>> db = SDBSession('database.sdb', create=True)
@@ -218,105 +245,229 @@ class SDBSession:
         sdb_Session = sessionmaker(bind=self.sdb_engine)
         self.session = sdb_Session()
         if kwargs.get("create", False):
-            self.session.add_all(initial_values())
-            self.session.add_all(initial_meta())
+            meta = default_meta()
+            meta.update(kwargs.get("meta", {}))
+            self.session.add_all(default_initial_values())
+            self.session.add_all([Meta(name=n, value=v) for n, v in meta.items()])
             self.session.commit()
+        self.autocommit = kwargs.get("autocommit", False)
         # add listeners
         event.listen(self.session, "before_commit", before_commit_meta_update)
         event.listen(Unit, "before_insert", before_insert_pos_update)
         event.listen(Structype, "before_insert", before_insert_pos_update)
         event.listen(Tag, "before_insert", before_insert_pos_update)
 
+    def __repr__(self):
+        return self.info()
+
+    def info(self, data=False):
+        lines = []
+        lines.append(f"PySDB database version: {self.meta('version').value}")
+        lines.append(f"PySDB database CRS: {self.meta('crs').value}")
+        lines.append(f"PySDB database created: {self.meta('created').value}")
+        lines.append(f"PySDB database updated: {self.meta('created').value}")
+        lines.append(f"Number of sites: {self.session.query(Site).count()}")
+        lines.append(f"Number of units: {self.session.query(Unit).count()}")
+        lines.append(f"Number of structures: {self.session.query(Structype).count()}")
+        lines.append(
+            f"Number of measurements: {self.session.query(Structdata).count()}"
+        )
+        if data:
+            for s in self.structypes():
+                n = self.session.query(Structdata).filter_by(structype=s).count()
+                if n > 0:
+                    lines.append(f"Number of {s.structure} measurements: {n}")
+        return "\n".join(lines)
+
     def close(self):
+        """
+        Close session
+
+        """
         self.session.close()
 
     def commit(self):
+        """
+        commit session
+
+        """
         self.session.commit()
 
-    def site(self, **kwargs):
+    def rollback(self):
         """
-        Insert or retrieve Site
-        """
-        assert "name" in kwargs, "name must be provided for site"
-        site = self.session.query(Site).filter_by(name=kwargs["name"]).first()
-        if site is None:
-            assert "unit" in kwargs, "unit must be provided to create site"
-            site = Site(**kwargs)
-            self.session.add(site)
-            self.commit()
-        return site
+        rollback session
 
-    def unit(self, **kwargs):
         """
-        Insert or retrieve Unit
-        """
-        assert "name" in kwargs, "name must be provided for unit"
-        unit = self.session.query(Unit).filter_by(name=kwargs["name"]).first()
-        if unit is None:
-            unit = Unit(**kwargs)
-            self.session.add(unit)
-            self.commit()
-        return unit
+        self.session.rollback()
 
-    def tag(self, **kwargs):
+    def meta(self, name, **kwargs):
         """
-        Insert or retrieve Tag
-        """
-        assert "name" in kwargs, "name must be provided for tag"
-        tag = self.session.query(Tag).filter_by(name=kwargs["name"]).first()
-        if tag is None:
-            tag = Tag(**kwargs)
-            self.session.add(tag)
-            self.commit()
-        return tag
+        Query Meta when no kwargs or insert/update when kwargs provided
 
-    def structype(self, **kwargs):
-        """
-        Insert or retrieve Structype
-        """
-        assert "structure" in kwargs, "structure must be provided for structype"
-        structype = (
-            self.session.query(Structype)
-            .filter_by(structure=kwargs["structure"])
-            .first()
-        )
-        if structype is None:
-            structype = Structype(**kwargs)
-            self.session.add(structype)
-            self.commit()
-        return structype
-
-    def add_structdata(self, **kwargs):
-        """
-        Add measurement to site
+        Args:
+            name (str): meta name
 
         Keyword Args:
-            site(Site): site instance
-            structype(Structype): structype instance
-            azimuth(float): dip direction or plunge direction
-            inclination(float): dip or plunge
+            value (str): meta value
+
+        Returns:
+            Meta
+        """
+        meta = self.session.query(Meta).filter_by(name=name).first()
+        if kwargs:
+            if meta is None:
+                meta = Meta(name=name, **kwargs)
+                self.session.add(meta)
+            else:
+                self.session.query(Meta).filter_by(name=name).update(kwargs)
+            if self.autocommit:
+                self.commit()
+        return meta
+
+    def site(self, name, **kwargs):
+        """
+        Query Site when no kwargs or insert/update when kwargs provided
+
+        Args:
+            name (str): site name
+
+        Keyword Args:
+            x_coord (float): x coord or longitude
+            y_coord (float): y coord or latitude
+            description (str): site description
+            unit (Unit): unit instance (mus be provided)
+
+        Returns:
+            Site
+        """
+        site = self.session.query(Site).filter_by(name=name).first()
+        if kwargs:
+            if site is None:
+                site = Site(name=name, **kwargs)
+                self.session.add(site)
+            else:
+                self.session.query(Site).filter_by(name=name).update(kwargs)
+            if self.autocommit:
+                self.commit()
+        return site
+
+    def unit(self, name, **kwargs):
+        """
+        Query Unit when no kwargs or insert/update when kwargs provided
+
+        Args:
+            name (str): unit name
+
+        Keyword Args:
+            description (str): unit description
+
+        Returns:
+            Unit
+        """
+        unit = self.session.query(Unit).filter_by(name=name).first()
+        if kwargs:
+            if unit is None:
+                unit = Unit(name=name, **kwargs)
+                self.session.add(unit)
+            else:
+                self.session.query(Unit).filter_by(name=name).update(kwargs)
+            if self.autocommit:
+                self.commit()
+        return unit
+
+    def tag(self, name, **kwargs):
+        """
+        Query Tag when no kwargs or insert/update when kwargs provided
+
+        Args:
+            name (str): tag name
+
+        Keyword Args:
+            description (str): tag description
+
+        Returns:
+            Tag
+        """
+        tag = self.session.query(Tag).filter_by(name=name).first()
+        if kwargs:
+            if tag is None:
+                tag = Tag(name=name, **kwargs)
+                self.session.add(tag)
+            else:
+                self.session.query(Tag).filter_by(name=name).update(kwargs)
+            if self.autocommit:
+                self.commit()
+        return tag
+
+    def structype(self, structure, **kwargs):
+        """
+        Query Structype when no kwargs or insert/update when kwargs provided
+
+        Args:
+            structure (str): label used for structure
+
+        Keyword Args:
+            description (str): Structype description
+            planar (int): 1 for planar 0 for linear Structype
+            structcode (int): structcode (optional)
+            groupcode (int): groupcode (optional)
+
+        Returns:
+            Structype
+        """
+        structype = self.session.query(Structype).filter_by(structure=structure).first()
+        if kwargs:
+            if structype is None:
+                structype = Structype(structure=structure, **kwargs)
+                self.session.add(structype)
+            else:
+                self.session.query(Structype).filter_by(structure=structure).update(
+                    kwargs
+                )
+            if self.autocommit:
+                self.commit()
+        return structype
+
+    def add_structdata(self, site, structype, azimuth, inclination, **kwargs):
+        """
+        Add structural measurement to site
+
+        Args:
+            site (Site): Site instance
+            structype (Structype): Structype instance
+            azimuth (float): dip direction or plunge direction
+            inclination (float): dip or plunge
+
+        Keyword Args:
+            description (str): structdata description
 
         Returns:
             Structdata
 
         """
-        assert "site" in kwargs, "site must be provided for structdata"
-        assert "structype" in kwargs, "structype must be provided for structdata"
-        data = Structdata(**kwargs)
+        data = Structdata(
+            site=site,
+            structype=structype,
+            azimuth=azimuth,
+            inclination=inclination,
+            **kwargs,
+        )
         self.session.add(data)
-        self.commit()
+        if self.autocommit:
+            self.commit()
         return data
 
-    def add_fol(self, fol, **kwargs):
+    def add_fol(self, site, structype, fol, **kwargs):
         """
         Add Foliation to site
 
         Args:
-            fol (Foliation): foliation instance
+            site (Site): Site instance
+            structype (Structype): Structype instance
+            fol (Foliation): Foliation instance
 
         Keyword Args:
-            site(Site): site instance
-            structype(Structype): structype instance
+            description (str): structdata description
 
         Returns:
             Structdata
@@ -325,24 +476,21 @@ class SDBSession:
         assert isinstance(
             fol, Foliation
         ), "fol argument must be instance of Foliation class"
-        assert "site" in kwargs, "site must be provided for structdata"
-        assert "structype" in kwargs, "structype must be provided for structdata"
-        assert kwargs["structype"].planar, "structype must be planar"
-        azi, inc = fol.geo
-        kwargs["azimuth"] = azi
-        kwargs["inclination"] = inc
-        return self.add_structdata(**kwargs)
+        assert structype.planar, "structype must be planar"
+        azimuth, inclination = fol.geo
+        return self.add_structdata(site, structype, azimuth, inclination, **kwargs)
 
-    def add_lin(self, lin, **kwargs):
+    def add_lin(self, site, structype, lin, **kwargs):
         """
         Add Lineation to site
 
         Args:
-            lin (Lineation): lineation instance
+            site (Site): Site instance
+            structype (Structype): Structype instance
+            lin (Lineation): Lineation instance
 
         Keyword Args:
-            site(Site): site instance
-            structype(Structype): structype instance
+            description (str): structdata description
 
         Returns:
             Structdata
@@ -351,54 +499,54 @@ class SDBSession:
         assert isinstance(
             lin, Lineation
         ), "lin argument must be instance of Lineation class"
-        assert "site" in kwargs, "site must be provided for structdata"
-        assert "structype" in kwargs, "structype must be provided for structdata"
-        assert not kwargs["structype"].planar, "structype must be linear"
-        azi, inc = lin.geo
-        kwargs["azimuth"] = azi
-        kwargs["inclination"] = inc
-        return self.add_structdata(**kwargs)
+        assert not structype.planar, "structype must be linear"
+        azimuth, inclination = lin.geo
+        return self.add_structdata(site, structype, azimuth, inclination, **kwargs)
 
-    def attach(self, fol, lin):
+    def attach(self, planar, linear):
         """
-        Add Lineation to site
+        Attach Foliation to Lineation
 
         Args:
-            fol (Foliation): foliation instance
-            lin (Lineation): lineation instance
+            planar (Structdata): planar Structdata
+            linear (Structdata): linear Structdata
 
         Returns:
             Attached
 
         """
-        pair = Attached(planar=fol, linear=lin)
+        assert planar.structype.planar == 1, "First argument must be planar Structdata"
+        assert linear.structype.planar == 0, "Second argument must be linear Structdata"
+        pair = Attached(planar=planar, linear=linear)
         self.session.add(pair)
-        self.commit()
+        if self.autocommit:
+            self.commit()
         return pair
 
-    def add_pair(self, pair, foltype, lintype, **kwargs):
+    def add_pair(self, site, foltype, lintype, pair, **kwargs):
         """
-        Add attached foliation and lineation to database
+        Add attached foliation and lineation to database. Note that
+        measurements of foliation and lineation are corrected.
 
         Args:
-            pair (Pair): pair instance
+            site (Site): site instance
             foltype (Structype): structype instance
             lintype (Structype): structype instance
+            pair (Pair): Pair instance
 
         Returns:
             Attached
 
         """
         assert isinstance(pair, Pair), "pair argument must be instance of Pair class"
-        kwargs["structype"] = foltype
-        fol = self.add_fol(pair.fol, **kwargs)
-        kwargs["structype"] = lintype
-        lin = self.add_lin(pair.lin, **kwargs)
+        fol = self.add_fol(site, foltype, pair.fol, **kwargs)
+        lin = self.add_lin(site, lintype, pair.lin, **kwargs)
         return self.attach(fol, lin)
 
     def sites(self, **kwargs):
         """
-        Retrieve Site or list of Sites based on criteria in kwargs
+        Retrieve list of Site instances filtered by kwargs. If query results
+        in single site, instance of Site is returned.
 
         Keyword arguments are passed to sqlalchemy filter_by method
         """
@@ -413,7 +561,8 @@ class SDBSession:
 
     def units(self, **kwargs):
         """
-        Retrieve Unit or list of Units based on criteria in kwargs
+        Retrieve list of Unit instances filtered by kwargs. If query results
+        in single unit, instance of Unit is returned.
 
         Keyword arguments are passed to sqlalchemy filter_by method
         """
@@ -428,7 +577,8 @@ class SDBSession:
 
     def structypes(self, **kwargs):
         """
-        Retrieve Structype or list of Structypes based on criteria in kwargs
+        Retrieve list of Structype instances filtered by kwargs. If query results
+        in single structural type, instance of Structype is returned.
 
         Keyword arguments are passed to sqlalchemy filter_by method
         """
@@ -443,7 +593,8 @@ class SDBSession:
 
     def tags(self, **kwargs):
         """
-        Retrieve Tag or list of Tags based on criteria in kwargs
+        Retrieve list of Tag instances filtered by kwargs. If query results
+        in single tag, instance of Tag is returned.
 
         Keyword arguments are passed to sqlalchemy filter_by method
         """
@@ -469,14 +620,14 @@ class SDBSession:
             structypes = (
                 self.session.query(Structype).filter_by(structure=structype).all()
             )
-            assert len(structypes) == 1, f"There is no structure {structype} in db"
+            assert len(structypes) == 1, f"There is no structure {structype} in db."
             structype = structypes[0]
         data = (
             self.session.query(Structdata)
             .filter_by(structype=structype, **kwargs)
             .all()
         )
-        if structype.planar:
+        if structype.planar == 1:
             res = FoliationSet(
                 [Foliation(v.azimuth, v.inclination) for v in data],
                 name=structype.structure,
