@@ -14,13 +14,14 @@ def ensure_arguments(*datatypes):
                 try:
                     nargs[ix] = cls(nargs[ix])
                     ok.append(True)
-                except:
+                except Exception:
                     ok.append(False)
             if all(ok):
                 return method(self, *nargs, **kwargs)
             else:
                 raise TypeError(
-                    f'Unsupported arguments for {method.__name__}. Must be {" or ".join([dt.__name__ for dt in datatypes])}'
+                    f'Unsupported arguments for {method.__name__}. \
+                      Must be {" or ".join([dt.__name__ for dt in datatypes])}'
                 )
 
         return wrapper
