@@ -6,11 +6,11 @@ from scipy.stats import vonmises
 from scipy.cluster.hierarchy import linkage, fcluster, dendrogram
 
 from apsg.config import apsg_conf
-from apsg.helpers._math import sind, cosd, atan2d
 from apsg.math._vector import Vector2, Vector3
 from apsg.helpers._math import acosd
 from apsg.feature._geodata import Lineation, Foliation, Pair, Fault, Cone
-from apsg.feature._tensor3 import OrientationTensor3, Ellipsoid
+from apsg.feature._tensor3 import OrientationTensor3, Ellipsoid, DeformationGradient3
+from apsg.feature._tensor2 import OrientationTensor2, Ellipse
 from apsg.feature._statistics import KentDistribution, vonMisesFisher
 
 
@@ -48,7 +48,7 @@ class FeatureSet:
         """Return label"""
         return self.name
 
-    def __array__(self, dtype=None):
+    def __array__(self, dtype=None, copy=None):
         return np.array([np.array(p) for p in self.data], dtype=dtype)
 
     def __eq__(self, other):
@@ -74,7 +74,7 @@ class FeatureSet:
             return type(self)([self.data[ix] for ix in idxs])
         else:
             raise TypeError(
-                "Wrong index. Only slice, int and numpy array for fancy indexing are allowed."
+                "Wrong index. Only slice, int and np.array are allowed for indexing."
             )
 
     def __iter__(self):
@@ -84,7 +84,7 @@ class FeatureSet:
         if isinstance(other, type(self)):
             return type(self)(self.data + other.data, name=self.name)
         else:
-            raise TypeError("Only {self.__name__} is allowed")
+            raise TypeError(f"Only {self.__name__} is allowed")
 
     def rotate(self, axis, phi):
         """Rotate ``FeatureSet`` object `phi` degress about `axis`."""
@@ -102,9 +102,9 @@ class FeatureSet:
           >>> l = Vector3Set.random_fisher(n=100, position=lin(120,40))
           >>> sm = [lb.R() for lb in l.bootstrap()]
           >>> l.fisher_statistics()
-          {'k': 19.912361106049794, 'a95': 3.2490273703993973, 'csd': 18.151964734256303}
+          {'k': 19.91236110604979, 'a95': 3.249027370399397, 'csd': 18.15196473425630}
           >>> Vector3Set(sm).fisher_statistics()
-          {'k': 1735.3602067018592, 'a95': 0.33932243564473413, 'csd': 1.9444205467798013}
+          {'k': 1735.360206701859, 'a95': 0.3393224356447341, 'csd': 1.944420546779801}
         """
         if size is None:
             size = len(self)
@@ -142,18 +142,18 @@ class Vector2Set(FeatureSet):
         return np.asarray([e.direction for e in self]).T
 
     def proj(self, vec):
-        """Return projections of all features in ``FeatureSet`` onto vector."""
+        """Return projections of all features in ``Vector2Set`` onto vector."""
         return type(self)([e.project() for e in self], name=self.name)
 
     def dot(self, vec):
-        """Return array of dot products of all features in ``FeatureSet`` with vector."""
+        """Return array of dot products of all features in ``Vector2Set`` with vector."""
         return np.array([e.dot(vec) for e in self])
 
     def cross(self, other=None):
-        """Return cross products of all features in ``FeatureSet``
+        """Return cross products of all features in ``Vector2Set``
 
         Without arguments it returns cross product of all pairs in dataset.
-        If argument is ``FeatureSet`` of same length or single data object
+        If argument is ``Vector2Set`` of same length or single data object
         element-wise cross-products are calculated.
         """
         res = []
@@ -170,10 +170,10 @@ class Vector2Set(FeatureSet):
     __pow__ = cross
 
     def angle(self, other=None):
-        """Return angles of all data in ``FeatureSet`` object
+        """Return angles of all data in ``Vector2Set`` object
 
         Without arguments it returns angles of all pairs in dataset.
-        If argument is ``FeatureSet`` of same length or single data object
+        If argument is ``Vector2Set`` of same length or single data object
         element-wise angles are calculated.
         """
         res = []
@@ -188,16 +188,16 @@ class Vector2Set(FeatureSet):
         return np.asarray(res)
 
     def normalized(self):
-        """Return ``FeatureSet`` object with normalized (unit length) elements."""
+        """Return ``Vector2Set`` object with normalized (unit length) elements."""
         return type(self)([e.normalized() for e in self], name=self.name)
 
     uv = normalized
 
     def transform(self, F, **kwargs):
-        """Return affine transformation of all features ``FeatureSet`` by matrix 'F'.
+        """Return affine transformation of all features ``Vector2Set`` by matrix 'F'.
 
         Args:
-          F: Transformation matrix. Should be array-like value e.g. ``DeformationGradient3``
+          F: Transformation matrix. Array-like value e.g. ``DeformationGradient3``
 
         Keyword Args:
           norm: normalize transformed features. True or False. Default False
@@ -206,12 +206,12 @@ class Vector2Set(FeatureSet):
         return type(self)([e.transform(F, **kwargs) for e in self], name=self.name)
 
     def R(self, mean=False):
-        """Return resultant of data in ``FeatureSet`` object.
+        """Return resultant of data in ``Vector2Set`` object.
 
-        Resultant is of same type as features in ``FeatureSet``. Note
-        that ``Foliation`` and ``Lineation`` are axial in nature so
-        resultant can give other result than expected. Anyway for axial
-        data orientation tensor analysis will give you right answer.
+        Resultant is of same type as features in ``Vector2Set``. Note
+        that ``Axial2`` is axial in nature so resultant can give
+        other result than expected. Anyway for axial data orientation
+        tensor analysis will give you right answer.
 
         Args:
             mean: if True returns mean resultant. Default False
@@ -254,7 +254,7 @@ class Vector2Set(FeatureSet):
         return acosd(abs(self.R(mean=True)))
 
     def rdegree(self):
-        """Degree of preffered orientation of vectors in ``FeatureSet``.
+        """Degree of preffered orientation of vectors in ``Vector2Set``.
 
         D = 100 * (2 * abs(R) - n) / n
         """
@@ -268,35 +268,18 @@ class Vector2Set(FeatureSet):
 
     @property
     def _ortensor(self):
-        # if "ortensor" not in self._cache:
-        #     self._cache["ortensor"] = OrientationTensor2.from_features(self)
-        # return self._cache["ortensor"]
-        return NotImplemented
+        if "ortensor" not in self._cache:
+            self._cache["ortensor"] = OrientationTensor2.from_features(self)
+        return self._cache["ortensor"]
 
     @property
     def _svd(self):
-        # if "svd" not in self._cache:
-        #     self._cache["svd"] = np.linalg.svd(self._ortensor)
-        # return self._cache["svd"]
-        return NotImplemented
-
-    def centered(self, max_vertical=False):
-        """Rotate ``FeatureSet`` object to position that eigenvectors are parallel
-        to axes of coordinate system: E1||X (north-south), E2||X(east-west),
-        E3||X(vertical)
-
-        Args:
-            max_vertical: If True E1 is rotated to vertical. Default False
-
-        """
-        # if max_vertical:
-        #     return self.transform(self._svd[2]).rotate(Vector3(0, -1, 0), 90)
-        # else:
-        #     return self.transform(self._svd[2])
-        return NotImplemented
+        if "svd" not in self._cache:
+            self._cache["svd"] = np.linalg.svd(self._ortensor)
+        return self._cache["svd"]
 
     def halfspace(self):
-        """Change orientation of vectors in ``FeatureSet``, so all have angle<=90 with
+        """Change orientation of vectors in ``Vector2Set``, so all have angle<=90 with
         resultant.
 
         """
@@ -313,18 +296,15 @@ class Vector2Set(FeatureSet):
                 alldone = np.all(v.angle(v.R()) <= 90)
         return type(self)([dtype_cls(vec) for vec in v], name=self.name)
 
-    def cluster(self):
-        return NotImplemented
-
     @classmethod
     def from_direction(cls, angles, name="Default"):
-        """Create ``FeatureSet`` object from arrays of direction angles
+        """Create ``Vector2Set`` object from arrays of direction angles
 
         Args:
           angles: list or angles
 
         Keyword Args:
-          name: name of ``FeatureSet`` object. Default is 'Default'
+          name: name of ``Vector2Set`` object. Default is 'Default'
 
         Example:
           >>> f = vec2set.from_angles([120,130,140,125, 132. 131])
@@ -334,14 +314,14 @@ class Vector2Set(FeatureSet):
 
     @classmethod
     def from_xy(cls, x, y, name="Default"):
-        """Create ``FeatureSet`` object from arrays of x and y components
+        """Create ``Vector2Set`` object from arrays of x and y components
 
         Args:
           x: list or array of x components
           y: list or array of y components
 
         Keyword Args:
-          name: name of ``FeatureSet`` object. Default is 'Default'
+          name: name of ``Vector2Set`` object. Default is 'Default'
 
         Example:
           >>> v = vec2set.from_xy([-0.4330127, -0.4330127, -0.66793414],
@@ -352,7 +332,8 @@ class Vector2Set(FeatureSet):
 
     @classmethod
     def random(cls, n=100, name="Default"):
-        """Method to create ``FeatureSet`` of features with uniformly distributed random orientation.
+        """Method to create ``Vector2Set`` of features with uniformly distributed
+        random orientation.
 
         Keyword Args:
           n: number of objects to be generated
@@ -368,7 +349,7 @@ class Vector2Set(FeatureSet):
 
     @classmethod
     def random_vonmises(cls, n=100, position=0, kappa=5, name="Default"):
-        """Return ``FeatureSet`` of random vectors sampled from von Mises distribution
+        """Return ``Vector2Set`` of random vectors sampled from von Mises distribution
         around center position with concentration kappa.
 
         Args:
@@ -436,6 +417,8 @@ class Vector3Set(FeatureSet):
         """Return projections of all features in ``FeatureSet`` onto vector."""
         return type(self)([e.project(vec) for e in self], name=self.name)
 
+    proj = project
+
     def reject(self, vec):
         """Return rejections of all features in ``FeatureSet`` onto vector."""
         return type(self)([e.reject(vec) for e in self], name=self.name)
@@ -492,7 +475,7 @@ class Vector3Set(FeatureSet):
         """Return affine transformation of all features ``FeatureSet`` by matrix 'F'.
 
         Args:
-          F: Transformation matrix. Should be array-like value e.g. ``DeformationGradient3``
+          F: Transformation matrix. Array-like value e.g. ``DeformationGradient3``
 
         Keyword Args:
           norm: normalize transformed features. True or False. Default False
@@ -627,9 +610,6 @@ class Vector3Set(FeatureSet):
                 alldone = np.all(v.angle(v.R()) <= 90)
         return type(self)([dtype_cls(vec) for vec in v], name=self.name)
 
-    def cluster(self):
-        return NotImplemented
-
     @classmethod
     def from_csv(cls, filename, acol=0, icol=1):
         """Create ``FeatureSet`` object from csv file of azimuths and inclinations
@@ -767,8 +747,8 @@ class Vector3Set(FeatureSet):
 
     @classmethod
     def random_fisher(cls, n=100, position=Vector3(0, 0, 1), kappa=20, name="Default"):
-        """Return ``FeatureSet`` of random vectors sampled from von Mises Fisher distribution
-        around center position with concentration kappa.
+        """Return ``FeatureSet`` of random vectors sampled from von Mises Fisher
+        distribution around center position with concentration kappa.
 
         Args:
           n: number of objects to be generated
@@ -788,8 +768,8 @@ class Vector3Set(FeatureSet):
         """Method to create ``FeatureSet`` of vectors distributed according to
         Fisher distribution.
 
-        Note: For proper von Mises Fisher distrinbution implementation use ``random.fisher``
-        method.
+        Note: For proper von Mises Fisher distrinbution implementation use
+        ``random.fisher`` method.
 
         Args:
           n: number of objects to be generated
@@ -922,7 +902,7 @@ class PairSet(FeatureSet):
     def __repr__(self):
         return f"P({len(self)}) {self.name}"
 
-    def __array__(self, dtype=None):
+    def __array__(self, dtype=None, copy=None):
         return np.array([np.array(p) for p in self.data], dtype=dtype)
 
     @property
@@ -958,6 +938,45 @@ class PairSet(FeatureSet):
         """
         return Vector3Set([e.rax for e in self], name=self.name)
 
+    def angle(self, other=None):
+        """Return angles of all data in ``PairSet`` object
+
+        Without arguments it returns angles of all pairs in dataset.
+        If argument is ``PairSet`` of same length or single data object
+        element-wise angles are calculated.
+        """
+        res = []
+        if other is None:
+            res = [
+                abs(
+                    DeformationGradient3.from_two_pairs(
+                        e, f, symmetry=True
+                    ).axisangle()[1]
+                )
+                for e, f in combinations(self.data, 2)
+            ]
+        elif issubclass(type(other), PairSet):
+            res = [
+                abs(
+                    DeformationGradient3.from_two_pairs(
+                        e, f, symmetry=True
+                    ).axisangle()[1]
+                )
+                for e, f in zip(self, other)
+            ]
+        elif issubclass(type(other), Pair):
+            res = [
+                abs(
+                    DeformationGradient3.from_two_pairs(
+                        e, other, symmetry=True
+                    ).axisangle()[1]
+                )
+                for e in self
+            ]
+        else:
+            raise TypeError("Wrong argument type!")
+        return np.asarray(res)
+
     @property
     def ortensor(self):
         """Return Lisle (1989) orientation tensor ``OrientationTensor3`` of orientations
@@ -1131,6 +1150,45 @@ class FaultSet(PairSet):
         """Return dihedra planes of FaultSet as FoliationSet"""
         return FoliationSet([e.d for e in self], name=self.name + "-D")
 
+    def angle(self, other=None):
+        """Return angles of all data in ``FaultSet`` object
+
+        Without arguments it returns angles of all pairs in dataset.
+        If argument is ``FaultSet`` of same length or single data object
+        element-wise angles are calculated.
+        """
+        res = []
+        if other is None:
+            res = [
+                abs(
+                    DeformationGradient3.from_two_pairs(
+                        e, f, symmetry=False
+                    ).axisangle()[1]
+                )
+                for e, f in combinations(self.data, 2)
+            ]
+        elif issubclass(type(other), FaultSet):
+            res = [
+                abs(
+                    DeformationGradient3.from_two_pairs(
+                        e, f, symmetry=False
+                    ).axisangle()[1]
+                )
+                for e, f in zip(self, other)
+            ]
+        elif issubclass(type(other), Fault):
+            res = [
+                abs(
+                    DeformationGradient3.from_two_pairs(
+                        e, other, symmetry=False
+                    ).axisangle()[1]
+                )
+                for e in self
+            ]
+        else:
+            raise TypeError("Wrong argument type!")
+        return np.asarray(res)
+
     @classmethod
     def random(cls, n=25):
         """Create PairSet of random pairs"""
@@ -1279,18 +1337,18 @@ class EllipseSet(FeatureSet):
     __feature_type__ = "Ellipse"
 
     @property
-    def lambda1(self) -> np.ndarray:
+    def S1(self) -> np.ndarray:
         """
-        Return the array of square root of maximum eigenvalues.
+        Return the array of maximum principal stretches.
         """
-        return np.array([e.lambda1 for e in self])
+        return np.array([e.S1 for e in self])
 
     @property
-    def lambda2(self) -> np.ndarray:
+    def S2(self) -> np.ndarray:
         """
-        Return the array of square root of minimum eigenvalues.
+        Return the array of minimum principal stretches.
         """
-        return np.array([e.lambda2 for e in self])
+        return np.array([e.S2 for e in self])
 
     @property
     def e1(self) -> np.ndarray:
@@ -1358,25 +1416,25 @@ class EllipsoidSet(FeatureSet):
         return np.array([e.shape for e in self])
 
     @property
-    def lambda1(self) -> np.ndarray:
+    def S1(self) -> np.ndarray:
         """
-        Return the array of the square root of maximum eigenvalue.
+        Return the array of maximum principal stretches.
         """
-        return np.array([e.lambda1 for e in self])
+        return np.array([e.S1 for e in self])
 
     @property
-    def lambda2(self) -> np.ndarray:
+    def S2(self) -> np.ndarray:
         """
-        Return the array of the square root of middle eigenvalue.
+        Return the array of middle principal stretches.
         """
-        return np.array([e.lambda2 for e in self])
+        return np.array([e.S2 for e in self])
 
     @property
-    def lambda3(self) -> np.ndarray:
+    def S3(self) -> np.ndarray:
         """
-        Return the array of the square root of minimum eigenvalue.
+        Return the array of minimum principal stretches.
         """
-        return np.array([e.lambda3 for e in self])
+        return np.array([e.S3 for e in self])
 
     @property
     def e1(self) -> np.ndarray:
@@ -1549,14 +1607,16 @@ class EllipsoidSet(FeatureSet):
     @property
     def MAD_l(self) -> np.ndarray:
         """
-        Return maximum angular deviation (MAD) of linearly distributed vectors. Kirschvink 1980
+        Return maximum angular deviation (MAD) of linearly distributed vectors.
+        Kirschvink 1980
         """
         return np.array([e.MAD_l for e in self])
 
     @property
     def MAD_p(self) -> np.ndarray:
         """
-        Return maximum angular deviation (MAD) of planarly distributed vectors. Kirschvink 1980
+        Return maximum angular deviation (MAD) of planarly distributed vectors.
+        Kirschvink 1980
         """
         return np.array([e.MAD_p for e in self])
 
@@ -1576,16 +1636,30 @@ class OrientationTensor3Set(EllipsoidSet):
     __feature_type__ = "OrientationTensor3"
 
 
-class Cluster(object):
+class ClusterSet(object):
     """
     Provides a hierarchical clustering using `scipy.cluster` routines.
-    The distance matrix is calculated as an angle between features, where ``Fol`` and
-    ``Lin`` use axial angles while ``Vec3`` uses direction angles.
+    The distance matrix is calculated as an angle between features, where ``Foliation``
+    and ``Lineation`` use axial angles while ``Vector3`` uses direction angles.
+
+    Args:
+        azi (float): plunge direction of linear feature in degrees
+        inc (float): plunge of linear feature in degrees
+
+    Keyword Args:
+        maxclust (int): Desired number of clusters. Default 2
+        angle (float): Forms flat clusters so that the original observations in each
+            cluster have no greater angle. Default is None to use maxclust criterion.
+        method (str): Method for calculating the distance between the newly formed
+            cluster and observations. Default is 'average' for UPGMA algorithm
+
     """
 
     def __init__(self, d, **kwargs):
-        assert isinstance(d, Vector2Set) or isinstance(
-            d, Vector3Set
+        assert (
+            isinstance(d, Vector2Set)
+            or isinstance(d, Vector3Set)
+            or isinstance(d, PairSet)
         ), "Only vec2set or vecset could be clustered"
         self.data = d.copy()
         self.maxclust = kwargs.get("maxclust", 2)
@@ -1598,13 +1672,13 @@ class Cluster(object):
     def __repr__(self):
         info = f"Already {len(self.groups)} clusters created."
         if self.angle is not None:
-            crit = "Criterion: Angle\nSettings: distance=%.4g\n" % (self.angle)
+            crit = f"Criterion: Angle\nSettings: distance={self.angle:.4g}\n"
         else:
-            crit = "Criterion: Maxclust\nSettings: muxclust=%.4g\n" % (self.maxclust)
+            crit = f"Criterion: Maxclust\nSettings: maxclust={self.maxclust:.4g}\n"
         return (
-            "Clustering object\n"
-            + "Number of data: %d\n" % len(self.data)
-            + "Linkage method: %s\n" % self.method
+            "ClusterSet\n"
+            + f"Number of data: {len(self.data)}\n"
+            + f"Linkage method: {self.method}\n"
             + crit
             + info
         )
@@ -1722,6 +1796,10 @@ def G(lst, name="Default"):
             return EllipsoidSet(lst, name=name)
         elif dtype_cls is OrientationTensor3:
             return OrientationTensor3Set(lst, name=name)
+        elif dtype_cls is Ellipse:
+            return EllipseSet(lst, name=name)
+        elif dtype_cls is OrientationTensor2:
+            return OrientationTensor2Set(lst, name=name)
         else:
             raise TypeError("Wrong datatype to create FeatureSet")
 
