@@ -23,6 +23,27 @@ class DeformationGradient2(Matrix2):
       >>> F = defgrad2(np.diag([2, 0.5]))
     """
 
+    @classmethod
+    def from_comp(cls, xx=1, xy=0, yx=0, yy=1):
+        """Return ``DeformationGradient2`` defined by individual components.
+        Default is zero tensor.
+
+        Keyword Args:
+            xx (float): tensor component F_xx
+            xy (float): tensor component F_xy
+            yx (float): tensor component F_yx
+            yy (float): tensor component F_yy
+
+        Example:
+            >>> F = matrix2.from_comp(xy=2)
+            >>> F
+            [[0. 2.]
+            [0. 0.]]
+
+        """
+
+        return cls([[xx, xy], [yx, yy]])
+
     @classmethod
     def from_ratio(cls, R=1):
         """Return isochoric ``DeformationGradient2`` tensor with axial stretches defined by strain ratio.
@@ -106,9 +127,7 @@ class DeformationGradient2(Matrix2):
 
     def velgrad(self, time=1):
         """Return ``VelocityGradient2`` for given time"""
-        from scipy.linalg import logm
-
-        return VelocityGradient2(logm(np.asarray(self)) / time)
+        return VelocityGradient2(spla.logm(np.asarray(self)) / time)
 
 
 class VelocityGradient2(Matrix2):
@@ -127,6 +146,27 @@ class VelocityGradient2(Matrix2):
 
     """
 
+    @classmethod
+    def from_comp(cls, xx=0, xy=0, yx=0, yy=0):
+        """Return ``VelocityGradient2`` defined by individual components.
+        Default is zero tensor.
+
+        Keyword Args:
+            xx (float): tensor component L_xx
+            xy (float): tensor component L_xy
+            yx (float): tensor component L_yx
+            yy (float): tensor component L_yy
+
+        Example:
+            >>> L = velgrad2.from_comp(xy=2)
+            >>> L
+            [[0. 2.]
+             [0. 0.]]
+
+        """
+
+        return cls([[xx, xy], [yx, yy]])
+
     def defgrad(self, time=1, steps=1):
         """
         Return ``DeformationGradient2`` tensor accumulated after given time.
@@ -136,15 +176,13 @@ class VelocityGradient2(Matrix2):
             steps (int): when bigger than 1, will return a list
                          of ``DeformationGradient2`` tensors for each timestep.
         """
-        from scipy.linalg import expm
-
         if steps > 1:  # FIX once container for matrix will be implemented
             return [
-                DeformationGradient2(expm(np.asarray(self) * t))
+                DeformationGradient2(spla.expm(np.asarray(self) * t))
                 for t in np.linspace(0, time, steps)
             ]
         else:
-            return DeformationGradient2(expm(np.asarray(self) * time))
+            return DeformationGradient2(spla.expm(np.asarray(self) * time))
 
     def rate(self):
         """
@@ -379,7 +417,7 @@ class Ellipse(Tensor2):
       Ellipse
       [[8. 0.]
        [0. 2.]]
-      (ar:2, ori:90)
+      (ar:2, ori:0)
 
     """
 
@@ -415,16 +453,16 @@ class Ellipse(Tensor2):
         return cls([[x * x, 0], [0, y * y]], **kwargs)
 
     @property
-    def lambda1(self) -> float:
+    def S1(self) -> float:
         """
-        Return the square root of maximum eigenvalue.
+        Return the maximum  principal stretch.
         """
         return math.sqrt(self.E1)
 
     @property
-    def lambda2(self) -> float:
+    def S2(self) -> float:
         """
-        Return the square root of minimum eigenvalue.
+        Return the minimum principal stretch.
         """
         return math.sqrt(self.E2)
 
@@ -433,28 +471,28 @@ class Ellipse(Tensor2):
         """
         Return the maximum natural principal strain.
         """
-        return math.log(self.lambda1)
+        return math.log(self.S1)
 
     @property
     def e2(self) -> float:
         """
         Return the minimum natural principal strain.
         """
-        return math.log(self.lambda2)
+        return math.log(self.S2)
 
     @property
     def ar(self) -> float:
         """
-        Return the lambda1/lambda2 ratio.
+        Return the ellipse axial ratio.
         """
-        return self.lambda1 / self.lambda2
+        return self.S1 / self.S2
 
     @property
     def orientation(self):
         """
         Return the orientation of the maximum eigenvector.
         """
-        return self.eigenvectors()[np.argmax(self.eigenvalues())].direction % 180
+        return self.V1.direction % 180
 
     @property
     def e12(self) -> float:
@@ -480,30 +518,32 @@ class OrientationTensor2(Ellipse):
       ``OrientationTensor2`` object
 
     Example:
-      >>> ot = ortensor2([[8, 0], [0, 2]])
+      >>> v = vec2set.random(n=1000)
+      >>> ot = v.ortensor()
       >>> ot
       OrientationTensor2
-      [[8. 0.]
-       [0. 2.]]
-      (ar:2, ori:90)
+      [[ 0.502 -0.011]
+       [-0.011  0.498]]
+      (ar:1.02, ori:140)
 
     """
 
     @classmethod
     def from_features(cls, g) -> "OrientationTensor2":
         """
-        Return ``Ortensor`` of data in ``Group``
+        Return ``Ortensor`` of data in Vector2Set features
 
         Args:
-            g: ``Group`` of ``Vector2``, ``Lin`` or ``Foliation``
+            g (Vector2Set): Set of features
 
         Example:
           >>> v = vec2set.random_vonmises(position=120)
-          >>> ortensor2.from_features(v)
+          >>> ot = v.ortensor()
+          >>> ot
           OrientationTensor2
-          [[ 0.684 -0.253]
-           [-0.253  0.316]]
-          (ar:2.09, ori:117)
+          [[ 0.377 -0.282]
+           [-0.282  0.623]]
+          (ar:2.05, ori:123)
 
         """
 
