@@ -25,10 +25,38 @@ class DeformationGradient3(Matrix3):
     """
 
     @classmethod
-    def from_ratios(cls, Rxy=1, Ryz=1):
-        """Return isochoric ``DeformationGradient3`` tensor with axial stretches defined by strain ratios.
+    def from_comp(cls, xx=1, xy=0, xz=0, yx=0, yy=1, yz=0, zx=0, zy=0, zz=1):
+        """Return ``DeformationGradient3`` defined by individual components.
         Default is identity tensor.
 
+        Keyword Args:
+            xx (float): tensor component F_xx
+            xy (float): tensor component F_xy
+            xz (float): tensor component F_xz
+            yx (float): tensor component F_yx
+            yy (float): tensor component F_yy
+            yz (float): tensor component F_yz
+            zx (float): tensor component F_zx
+            zy (float): tensor component F_zy
+            zz (float): tensor component F_zz
+
+        Example:
+            >>> F = defgrad.from_comp(xy=1, zy=-0.5)
+            >>> F
+            DeformationGradient3
+            [[ 1.   1.   0. ]
+             [ 0.   1.   0. ]
+             [ 0.  -0.5  1. ]]
+
+        """
+
+        return cls([[xx, xy, xz], [yx, yy, yz], [zx, zy, zz]])
+
+    @classmethod
+    def from_ratios(cls, Rxy=1, Ryz=1):
+        """Return isochoric ``DeformationGradient3`` tensor with axial stretches
+        defined by strain ratios. Default is identity tensor.
+
         Keyword Args:
           Rxy (float): XY strain ratio
           Ryz (float): YZ strain ratio
@@ -122,8 +150,8 @@ class DeformationGradient3(Matrix3):
         Return ``DeformationGradient3`` representing rotation of vector v1 to v2 around
         axis a.
 
-        If v1.angle(a) is not equal to v2.angle(b), the minimum adjustment of rotation axis
-        is done automatically.
+        If v1.angle(a) is not equal to v2.angle(b), the minimum adjustment of rotation
+        axis is done automatically.
 
         Args:
           v1: ``Vector3`` like object
@@ -163,6 +191,9 @@ class DeformationGradient3(Matrix3):
             p1 (``Pair``): from
             p2 (``Pair``): to
 
+        Keyword Args:
+          symmetry (bool): If True, returns minimum angle rotation of axial pairs
+
         Returns:
             ``Defgrad3`` rotational matrix
 
@@ -197,13 +228,15 @@ class DeformationGradient3(Matrix3):
 
     @property
     def U(self):
-        """Return stretching part of ``DeformationGradient3`` from right polar decomposition."""
+        """Return stretching part of ``DeformationGradient3`` from right polar
+        decomposition."""
         _, U = spla.polar(self, "right")
         return type(self)(U)
 
     @property
     def V(self):
-        """Return stretching part of ``DeformationGradient3`` from left polar decomposition."""
+        """Return stretching part of ``DeformationGradient3`` from left polar
+        decomposition."""
         _, V = spla.polar(self, "left")
         return type(self)(V)
 
@@ -224,11 +257,12 @@ class DeformationGradient3(Matrix3):
         else:
             sina = (R[2][1] + (cosa - 1.0) * axis.y * axis.z) / axis.x
         angle = np.rad2deg(np.arctan2(sina, cosa))
-        return axis, angle
+        return axis, float(angle)
 
     def velgrad(self, time=1):
         """
-        Return ``VelocityGradient3`` calculated as matrix logarithm divided by given time.
+        Return ``VelocityGradient3`` calculated as matrix logarithm divided by given
+        time.
 
         Keyword Args:
             time (float): total time. Default 1
@@ -248,9 +282,7 @@ class DeformationGradient3(Matrix3):
              [0.  0.  0.5]]
 
         """
-        from scipy.linalg import logm
-
-        return VelocityGradient3(logm(np.asarray(self)) / time)
+        return VelocityGradient3(spla.logm(np.asarray(self)) / time)
 
 
 class VelocityGradient3(Matrix3):
@@ -268,6 +300,33 @@ class VelocityGradient3(Matrix3):
       >>> L = velgrad(np.diag([0.1, 0, -0.1]))
     """
 
+    @classmethod
+    def from_comp(cls, xx=0, xy=0, xz=0, yx=0, yy=0, yz=0, zx=0, zy=0, zz=0):
+        """Return ``VelocityGradient3`` defined by individual components. Default is zero
+        tensor.
+
+        Keyword Args:
+            xx (float): tensor component L_xx
+            xy (float): tensor component L_xy
+            xz (float): tensor component L_xz
+            yx (float): tensor component L_yx
+            yy (float): tensor component L_yy
+            yz (float): tensor component L_yz
+            zx (float): tensor component L_zx
+            zy (float): tensor component L_zy
+            zz (float): tensor component L_zz
+
+        Example:
+            >>> L = velgrad.from_comp(xy=1, zy=-0.5)
+            >>> L
+            [[ 0.   1.   0. ]
+             [ 0.   0.   0. ]
+             [ 0.  -0.5  0. ]]
+
+        """
+
+        return cls([[xx, xy, xz], [yx, yy, yz], [zx, zy, zz]])
+
     def defgrad(self, time=1, steps=1):
         """
         Return ``DeformationGradient3`` tensor accumulated after given time.
@@ -277,15 +336,13 @@ class VelocityGradient3(Matrix3):
             steps (int): when bigger than 1, will return a list
                          of ``DeformationGradient3`` tensors for each timestep.
         """
-        from scipy.linalg import expm
-
         if steps > 1:  # FIX once container for matrix will be implemented
             return [
-                DeformationGradient3(expm(np.asarray(self) * t))
+                DeformationGradient3(spla.expm(np.asarray(self) * t))
                 for t in np.linspace(0, time, steps)
             ]
         else:
-            return DeformationGradient3(expm(np.asarray(self) * time))
+            return DeformationGradient3(spla.expm(np.asarray(self) * time))
 
     def rate(self):
         """
@@ -303,7 +360,6 @@ class VelocityGradient3(Matrix3):
 
 
 class Tensor3(Matrix3):
-    @property
     def eigenlins(self):
         """
         Return tuple of eigenvectors as ``Lineation`` objects.
@@ -311,7 +367,6 @@ class Tensor3(Matrix3):
 
         return tuple(Lineation(v) for v in self.eigenvectors())
 
-    @property
     def eigenfols(self):
         """
         Return tuple of eigenvectors as ``Foliation`` objects.
@@ -333,8 +388,24 @@ class Stress3(Tensor3):
     """
     The class to represent 3D stress tensor.
 
-    Note: Tensile normal stresses have positive values,
-    and compressive normal stresses have negative values.
+    The real eigenvalues of the stress tensor are what we call
+    the principal stresses. There are 3 of these in 3D, available
+    as properties E1, E2, and E3 in descending order of magnitude
+    (max, intermediate, and minimum principal stresses) with orientations
+    available as properties V1, V2 and V3. The minimum principal stress
+    is simply the eigenvalue that has the lowest magnitude. Therefore,
+    the maximum principal stress is the most tensile (least compressive)
+    and the minimum principal stress is the least tensile (most compressive).
+    Tensile normal stresses have positive values, and compressive normal
+    stresses have negative values. If the maximum principal stress is <=0
+    and the minimum principal stress is negative then the stresses are
+    completely compressive.
+
+    Note: Stress tensor has a special properties sigma1, sigma2 and sigma3
+    to follow common geological terminology. sigma1 is most compressive
+    (least tensile) while sigma3 is most tensile (least compressive).
+    Their orientation could be accessed with properties sigma1dir,
+    sigma2dir and sigma3dir.
 
     Args:
       a (3x3 array_like): Input data, that can be converted to
@@ -393,6 +464,16 @@ class Stress3(Tensor3):
 
         return type(self)(self - self.hydrostatic)
 
+    def effective(self, fp):
+        """
+        A effective stress tensor reduced by fluid pressure
+
+        Args:
+            fp (flot): fluid pressure
+        """
+
+        return type(self)(self + fp * Stress3())
+
     @property
     def sigma1(self):
         """
@@ -495,8 +576,8 @@ class Stress3(Tensor3):
     @property
     def diagonalized(self):
         """
-        Returns diagonalized Stress tensor and orthogonal matrix R, which transforms actual
-        coordinate system to the principal one.
+        Returns diagonalized Stress tensor and orthogonal matrix R, which transforms
+        actual coordinate system to the principal one.
 
         """
         return (
@@ -563,6 +644,40 @@ class Stress3(Tensor3):
         sn, tau = self.stress_comp(n)
         return abs(tau)
 
+    def slip_tendency(self, n, fp=0, log=False):
+        """
+        Return slip tendency calculated as the ratio of shear stress
+        to normal stress acting on the plane.
+
+        Note: Providing fluid pressure effective normal stress is calculated
+
+        Keyword Args:
+          fp (float): fluid pressure. Default 0
+          log (bool): when True, returns logarithm of slip tendency
+
+        """
+
+        Se = self.effective(fp)
+        sn, tau = Se.stress_comp(n)
+        if log:
+            return np.log(abs(tau) / abs(sn))
+        else:
+            return abs(tau) / abs(sn)
+
+    def dilation_tendency(self, n, fp=0):
+        """
+        Return dilation tendency of the plane.
+
+        Note: Providing fluid pressure effective stress is used
+
+        Keyword Args:
+          fp (float): fluid pressure. Default 0
+
+        """
+        Se = self.effective(fp)
+        sn, tau = Se.stress_comp(n)
+        return (Se.sigma1 - abs(sn)) / (Se.sigma1 - Se.sigma3)
+
     @property
     def shape_ratio(self):
         """
@@ -588,15 +703,18 @@ class Ellipsoid(Tensor3):
       >>> E = ellipsoid([[8, 0, 0], [0, 2, 0], [0, 0, 1]])
       >>> E
       Ellipsoid
-      [[8. 0. 0.]
-       [0. 2. 0.]
-       [0. 0. 1.]]
-      (λ1:2.83, λ2:1.41, λ3:1)
+      [[8 0 0]
+       [0 2 0]
+       [0 0 1]]
+      (S1:2.83, S2:1.41, S3:1)
 
     """
 
     def __repr__(self) -> str:
-        return f"{Matrix3.__repr__(self)}\n(λ1:{self.lambda1:.3g}, λ2:{self.lambda2:.3g}, λ3:{self.lambda3:.3g})"
+        return (
+            f"{Matrix3.__repr__(self)}\n"
+            f"(S1:{self.S1:.3g}, S2:{self.S2:.3g}, S3:{self.S3:.3g})"
+        )
 
     @classmethod
     def from_defgrad(cls, F, form="left", **kwargs) -> "Ellipsoid":
@@ -659,23 +777,23 @@ class Ellipsoid(Tensor3):
         return self.K
 
     @property
-    def lambda1(self) -> float:
+    def S1(self) -> float:
         """
-        Return the square root of maximum eigenvalue.
+        Return the maximum principal stretch.
         """
         return math.sqrt(self.E1)
 
     @property
-    def lambda2(self) -> float:
+    def S2(self) -> float:
         """
-        Return the square root of middle eigenvalue.
+        Return the middle principal stretch.
         """
         return math.sqrt(self.E2)
 
     @property
-    def lambda3(self) -> float:
+    def S3(self) -> float:
         """
-        Return the square root of minimum eigenvalue.
+        Return the minimum principal stretch.
         """
         return math.sqrt(self.E3)
 
@@ -684,35 +802,35 @@ class Ellipsoid(Tensor3):
         """
         Return the maximum natural principal strain.
         """
-        return math.log(self.lambda1)
+        return math.log(self.S1)
 
     @property
     def e2(self) -> float:
         """
         Return the middle natural principal strain.
         """
-        return math.log(self.lambda2)
+        return math.log(self.S2)
 
     @property
     def e3(self) -> float:
         """
         Return the minimum natural principal strain.
         """
-        return math.log(self.lambda3)
+        return math.log(self.S3)
 
     @property
     def Rxy(self) -> float:
         """
         Return the Rxy ratio.
         """
-        return self.lambda1 / self.lambda2 if self.lambda2 != 0 else np.inf
+        return self.S1 / self.S2 if self.S2 != 0 else float("inf")
 
     @property
     def Ryz(self) -> float:
         """
         Return the Ryz ratio.
         """
-        return self.lambda2 / self.lambda3 if self.lambda3 != 0 else np.inf
+        return self.S2 / self.S3 if self.S3 != 0 else float("inf")
 
     @property
     def e12(self) -> float:
@@ -740,7 +858,7 @@ class Ellipsoid(Tensor3):
         """
         Return the strain symmetry.
         """
-        return (self.Rxy - 1) / (self.Ryz - 1) if self.Ryz > 1 else np.inf
+        return (self.Rxy - 1) / (self.Ryz - 1) if self.Ryz > 1 else float("inf")
 
     @property
     def d(self) -> float:
@@ -754,7 +872,7 @@ class Ellipsoid(Tensor3):
         """
         Return the strain symmetry (Ramsay, 1983).
         """
-        return self.e12 / self.e23 if self.e23 > 0 else np.inf
+        return self.e12 / self.e23 if self.e23 > 0 else float("inf")
 
     @property
     def D(self) -> float:
@@ -833,7 +951,7 @@ class Ellipsoid(Tensor3):
         Intensity index (Lisle, 1985).
         """
 
-        return 7.5 * np.sum((np.array(self.eigenvalues()) - 1 / 3) ** 2)
+        return 7.5 * float(np.sum((np.array(self.eigenvalues()) - 1 / 3) ** 2))
 
     @property
     def aMAD_l(self) -> float:
@@ -841,7 +959,7 @@ class Ellipsoid(Tensor3):
         Return approximate angular deviation from the major axis along E1.
         """
 
-        return atand(np.sqrt((1 - self.E1) / self.E1))
+        return float(atand(np.sqrt((1 - self.E1) / self.E1)))
 
     @property
     def aMAD_p(self) -> float:
@@ -849,7 +967,7 @@ class Ellipsoid(Tensor3):
         Return approximate deviation from the plane normal to E3.
         """
 
-        return atand(np.sqrt(self.E3 / (1 - self.E3)))
+        return float(atand(np.sqrt(self.E3 / (1 - self.E3))))
 
     @property
     def aMAD(self) -> float:
@@ -869,7 +987,7 @@ class Ellipsoid(Tensor3):
 
         Kirschvink 1980
         """
-        return atand(np.sqrt((self.E2 + self.E3) / self.E1))
+        return float(atand(np.sqrt((self.E2 + self.E3) / self.E1)))
 
     @property
     def MAD_p(self) -> float:
@@ -878,7 +996,7 @@ class Ellipsoid(Tensor3):
 
         Kirschvink 1980
         """
-        return atand(np.sqrt(self.E3 / self.E2 + self.E3 / self.E1))
+        return float(atand(np.sqrt(self.E3 / self.E2 + self.E3 / self.E1)))
 
     @property
     def MAD(self) -> float:
@@ -911,47 +1029,55 @@ class OrientationTensor3(Ellipsoid):
       >>> ot = ortensor([[8, 0, 0], [0, 2, 0], [0, 0, 1]])
       >>> ot
       OrientationTensor3
-      [[8. 0. 0.]
-       [0. 2. 0.]
-       [0. 0. 1.]]
-      (λ1:2.83, λ2:1.41, λ3:1)
+      [[8 0 0]
+       [0 2 0]
+       [0 0 1]]
+      (S1:2.83, S2:1.41, S3:1)
 
     """
 
     @classmethod
     def from_features(cls, g) -> "OrientationTensor3":
         """
-        Return ``Ortensor`` of data in ``Group``
+        Return ``Ortensor`` of data in Vector3Set of features
 
         Args:
-            g: ``Group`` of ``Vector3``, ``Lin`` or ``Foliation``
+            g (Vector3Set): Set of features
 
         Example:
           >>> g = linset.random_fisher(position=lin(120,50))
           >>> ot = ortensor.from_features(g)
           >>> ot
           OrientationTensor3
-          [[ 0.142 -0.151 -0.212]
-           [-0.151  0.326  0.37 ]
-           [-0.212  0.37   0.532]]
-          (λ1:0.95, λ2:0.241, λ3:0.2)
-          >>> ot.eigenlins
-          (L:120/49, L:216/5, L:310/40)
+          [[ 0.126 -0.149 -0.202]
+           [-0.149  0.308  0.373]
+           [-0.202  0.373  0.566]]
+          (S1:0.955, S2:0.219, S3:0.2)
+          >>> ot.eigenlins()
+          (L:119/51, L:341/31, L:237/21)
 
         """
 
         return cls(np.dot(np.array(g).T, np.array(g)) / len(g))
 
     @classmethod
-    def from_pairs(cls, p) -> "OrientationTensor3":
+    def from_pairs(cls, p, shift=True) -> "OrientationTensor3":
         """
         Return Lisle (1989) ``Ortensor`` of orthogonal data in ``PairSet``
 
-        Lisle, R. (1989). The Statistical Analysis of Orthogonal Orientation Data. The Journal of Geology, 97(3), 360-364.
+        Lisle, R. (1989). The Statistical Analysis of Orthogonal Orientation Data.
+            The Journal of Geology, 97(3), 360-364.
+
+        Note: Tensor is by default shifted towards positive eigenvalues, so it
+            could be used as Scheidegger orientation tensor for plotting. When
+            original Lisle tensor is needed, set shift to False.
 
         Args:
             p: ``PairSet``
 
+        Keyword Args:
+            shift (bool): When True the tensor is shifted. Default True
+
         Example:
           >>> p = pairset([pair(109, 82, 21, 10),
                            pair(118, 76, 30, 11),
@@ -960,13 +1086,23 @@ class OrientationTensor3(Ellipsoid):
           >>> ot = ortensor.from_pairs(p)
           >>> ot
           OrientationTensor3
-          [[ 0.731  0.575  0.086]
-           [ 0.575 -0.725  0.224]
-           [ 0.086  0.224 -0.005]]
-          (λ1:0.98, λ2:0.978, λ3:0.0688)
+          [[0.577 0.192 0.029]
+           [0.192 0.092 0.075]
+           [0.029 0.075 0.332]]
+          (S1:0.807, S2:0.579, S3:0.114)
 
         """
-        return cls(
-            OrientationTensor3.from_features(p.lvec)
-            - OrientationTensor3.from_features(p.fvec)
-        )
+        if shift:
+            return cls(
+                (
+                    OrientationTensor3.from_features(p.lvec)
+                    - OrientationTensor3.from_features(p.fvec)
+                    + np.eye(3)
+                )
+                / 3
+            )
+        else:
+            return cls(
+                OrientationTensor3.from_features(p.lvec)
+                - OrientationTensor3.from_features(p.fvec)
+            )
