@@ -26,7 +26,7 @@ class Vector:
     def __hash__(self):
         return hash((type(self).__name__,) + self._coords)
 
-    def __array__(self, dtype=None):
+    def __array__(self, dtype=None, copy=None):
         return np.array(self._coords, dtype=dtype)
 
     def to_json(self):
@@ -84,9 +84,6 @@ class Vector:
 
     __pos__ = __copy__
 
-    def __pow__(self, other):
-        return type(self)(np.power(self, other))
-
     def __abs__(self):
         return math.sqrt(sum(map(lambda x: x * x, self._coords)))
 
@@ -173,7 +170,7 @@ class Vector2(Vector):
             coords = (1, 0)
         if len(args) == 1:
             if np.asarray(args[0]).shape == Vector2.__shape__:
-                coords = np.asarray(args[0])
+                coords = tuple(c.item() for c in np.asarray(args[0]))
             elif isinstance(args[0], str):
                 if args[0].lower() == "x":
                     coords = (1, 0)
@@ -375,7 +372,7 @@ class Vector3(Vector):
             coords = (1, 0, 0)
         elif len(args) == 1:
             if np.asarray(args[0]).shape == Vector3.__shape__:
-                coords = np.asarray(args[0])
+                coords = tuple(c.item() for c in np.asarray(args[0]))
             elif isinstance(args[0], str):
                 if args[0].lower() == "x":
                     coords = (1, 0, 0)
@@ -452,6 +449,12 @@ class Vector3(Vector):
         else:
             return float(r)
 
+    def __pow__(self, other):
+        if issubclass(type(other), Vector3):
+            return self.cross(other)
+        else:
+            return type(self)(np.power(self, other))
+
     @ensure_first_arg_same
     def cross(self, other):
         """
@@ -508,7 +511,9 @@ class Vector3(Vector):
 
     @ensure_first_arg_same
     def rotate(self, axis, theta):
-        """Return the vector rotated around axis through angle theta. Right hand rule applies"""
+        """Return the vector rotated around axis through angle theta. Right-hand rule
+        applies
+        """
         v = Vector3(self)  # ensure vector
         k = Vector3(axis.uv())
         return type(self)(
