@@ -5,8 +5,6 @@ import matplotlib.pyplot as plt
 from matplotlib.patches import Polygon
 
 from apsg.config import apsg_conf
-from apsg.feature._tensor3 import Ellipsoid
-from apsg.feature._container import EllipsoidSet
 from apsg.plotting._plot_artists import FabricPlotArtistFactory
 from apsg.feature import feature_from_json
 
@@ -14,7 +12,6 @@ __all__ = ["VollmerPlot", "RamsayPlot", "FlinnPlot", "HsuPlot"]
 
 
 class FabricPlot(object):
-
     """
     Metaclas for Fabric plots
     """
@@ -93,7 +90,7 @@ class FabricPlot(object):
                 numpoints=1,
             )
         if self._kwargs["title"] is not None:
-            self.fig.suptitle(self._kwargs["title"])
+            self.fig.suptitle(self._kwargs["title"], **self._kwargs["title_kws"])
         if self._kwargs["tight_layout"]:
             self.fig.tight_layout()
 
@@ -131,12 +128,13 @@ class FabricPlot(object):
 
 
 class VollmerPlot(FabricPlot):
-
     """
     Represents the triangular fabric plot (Vollmer, 1989).
 
     Keyword Args:
         title (str): figure title. Default None.
+        title_kws (dict): dictionary of keyword arguments passed to matplotlib suptitle
+            method.
         ticks (bool): Show ticks. Default True
         n_ticks (int): Number of ticks. Default 10
         tick_size (float): Size of ticks. Default 0.2
@@ -264,7 +262,6 @@ class VollmerPlot(FabricPlot):
     ########################################
 
     def _triplot(self, a, b, c, **kwargs):
-
         a = np.atleast_1d(a)
         b = np.atleast_1d(b)
         c = np.atleast_1d(c)
@@ -293,9 +290,27 @@ class VollmerPlot(FabricPlot):
 
 
 class RamsayPlot(FabricPlot):
-
     """
     Represents the Ramsay deformation plot.
+
+    Keyword Args:
+        title (str): figure title. Default None.
+        title_kws (dict): dictionary of keyword arguments passed to matplotlib suptitle
+            method.
+        ticks (bool): Show ticks. Default True
+        n_ticks (int): Number of ticks. Default 10
+        tick_size (float): Size of ticks. Default 0.2
+        margin (float): Size of margin. Default 0.05
+        grid (bool): Show grid. Default is True
+        grid_color (str): Matplotlib color of the grid. Default "k"
+        grid_style (str): Matplotlib style of the grid. Default ":"
+
+    Examples:
+        >>> l = linset.random_fisher(position=lin(120, 40))
+        >>> ot = l.ortensor()
+        >>> s = RamsayPlot(title="Point distribution")
+        >>> s.point(ot)
+        >>> s.show()
     """
 
     def __init__(self, *args, **kwargs):
@@ -368,9 +383,27 @@ class RamsayPlot(FabricPlot):
 
 
 class FlinnPlot(FabricPlot):
-
     """
     Represents the Ramsay deformation plot.
+
+    Keyword Args:
+        title (str): figure title. Default None.
+        title_kws (dict): dictionary of keyword arguments passed to matplotlib suptitle
+            method.
+        ticks (bool): Show ticks. Default True
+        n_ticks (int): Number of ticks. Default 10
+        tick_size (float): Size of ticks. Default 0.2
+        margin (float): Size of margin. Default 0.05
+        grid (bool): Show grid. Default is True
+        grid_color (str): Matplotlib color of the grid. Default "k"
+        grid_style (str): Matplotlib style of the grid. Default ":"
+
+    Examples:
+        >>> l = linset.random_fisher(position=lin(120, 40))
+        >>> ot = l.ortensor()
+        >>> s = FlinnPlot(title="Point distribution")
+        >>> s.point(ot)
+        >>> s.show()
     """
 
     def __init__(self, *args, **kwargs):
@@ -443,9 +476,27 @@ class FlinnPlot(FabricPlot):
 
 
 class HsuPlot(FabricPlot):
-
     """
     Represents the Hsu fabric plot.
+
+    Keyword Args:
+        title (str): figure title. Default None.
+        title_kws (dict): dictionary of keyword arguments passed to matplotlib suptitle
+            method.
+        ticks (bool): Show ticks. Default True
+        n_ticks (int): Number of ticks. Default 10
+        tick_size (float): Size of ticks. Default 0.2
+        margin (float): Size of margin. Default 0.05
+        grid (bool): Show grid. Default is True
+        grid_color (str): Matplotlib color of the grid. Default "k"
+        grid_style (str): Matplotlib style of the grid. Default ":"
+
+    Examples:
+        >>> l = linset.random_fisher(position=lin(120, 40))
+        >>> ot = l.ortensor()
+        >>> s = HsuPlot(title="Point distribution")
+        >>> s.point(ot)
+        >>> s.show()
     """
 
     def __init__(self, *args, **kwargs):
