@@ -1,4 +1,3 @@
-import sys
 import pickle
 
 import numpy as np
@@ -6,8 +5,6 @@ import matplotlib.pyplot as plt
 from scipy.stats import vonmises, circmean
 
 from apsg.config import apsg_conf
-from apsg.math._vector import Vector2
-from apsg.feature._container import Vector2Set
 from apsg.plotting._plot_artists import RosePlotArtistFactory
 from apsg.feature import feature_from_json
 
@@ -15,12 +12,13 @@ __all__ = ["RosePlot"]
 
 
 class RosePlot(object):
-
     """
     ``RosePlot`` class for rose histogram plotting.
 
     Keyword Args:
         title (str): figure title. Default None
+        title_kws (dict): dictionary of keyword arguments passed to matplotlib suptitle
+            method.
         bins (int): Number of bins. Default 36
         axial (bool): Directional data are axial. Defaut True
         density (bool): Use density instead of counts. Default False
@@ -30,7 +28,7 @@ class RosePlot(object):
         scaled (bool): Bins scaled by area instead value. Default False
         ticks (bool): show ticks. Default True
         grid (bool): show grid lines. Default False
-        grid_kw (dict): Dict passed to Axes.grid. Default {}
+        grid_kws (dict): Dict passed to Axes.grid. Default {}
 
         Other keyword arguments are passed to matplotlib plot.
 
@@ -56,7 +54,7 @@ class RosePlot(object):
         # self.ax.format_coord = self.format_coord
         self.ax.set_theta_direction(-1)
         self.ax.set_theta_zero_location("N")
-        self.ax.grid(self._kwargs["grid"], **self._kwargs["grid_kw"])
+        self.ax.grid(self._kwargs["grid"], **self._kwargs["grid_kws"])
 
     def _plot_artists(self):
         for artist in self._artists:
@@ -124,7 +122,7 @@ class RosePlot(object):
                 numpoints=1,
             )
         if self._kwargs["title"] is not None:
-            self.fig.suptitle(self._kwargs["title"])
+            self.fig.suptitle(self._kwargs["title"], **self._kwargs["title_kws"])
         if self._kwargs["tight_layout"]:
             self.fig.tight_layout()
 
@@ -165,7 +163,23 @@ class RosePlot(object):
     ########################################
 
     def bar(self, *args, **kwargs):
-        """Plot rose histogram of angles"""
+        """
+        Plot rose histogram of angles
+
+        Args:
+            Vector2Set feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ec (color): Patch edge color. Default None
+            fc (color): Patch face color. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+            legend (bool): Whether to show legend. Default False
+
+        """
         try:
             artist = RosePlotArtistFactory.create_bar(*args, **kwargs)
             self._artists.append(artist)
@@ -173,7 +187,25 @@ class RosePlot(object):
             print(err)
 
     def pdf(self, *args, **kwargs):
-        """Plot rose histogram of angles"""
+        """
+        Plot Von Mises probability density function from angles
+
+        Args:
+            Vector2Set feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ec (color): Patch edge color. Default None
+            fc (color): Patch face color. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+            legend (bool): Whether to show legend. Default False
+            weight (float): Factor to scale probability density function
+                Default 1
+
+        """
         try:
             artist = RosePlotArtistFactory.create_pdf(*args, **kwargs)
             self._artists.append(artist)
@@ -181,7 +213,23 @@ class RosePlot(object):
             print(err)
 
     def muci(self, *args, **kwargs):
-        """Plot circular mean with confidence interval"""
+        """
+        Plot circular mean with bootstrapped confidence interval
+
+        Args:
+            Vector2Set feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+            confidence_level (float): Confidence interval. Default 95
+            n_resamples (int): Number of bootstrapped samples.
+                Default 9999
+
+        """
         try:
             artist = RosePlotArtistFactory.create_muci(*args, **kwargs)
             self._artists.append(artist)
@@ -225,6 +273,7 @@ class RosePlot(object):
     def _pdf(self, *args, **kwargs):
         bottom = np.zeros_like(self._kwargs["pdf_res"])
         legend = kwargs.pop("legend")
+        weight = kwargs.pop("weight")
         theta = np.linspace(-np.pi, np.pi, self._kwargs["pdf_res"])
         for arg in args:
             ang = arg.direction % 360
@@ -248,6 +297,7 @@ class RosePlot(object):
                         theta, self._kwargs["kappa"], loc=np.radians(a)
                     )
             radii /= len(ang)
+            radii *= weight
             if self._kwargs["scaled"]:
                 radii = np.sqrt(radii)
             if legend:
