@@ -4,8 +4,6 @@ from matplotlib.patches import Circle
 import matplotlib.pyplot as plt
 
 from apsg.config import apsg_conf
-from apsg.feature._statistics import estimate_k
-from apsg.math._vector import Vector3
 from apsg.feature._geodata import Lineation
 from apsg.feature._container import Vector3Set
 from apsg.plotting._projection import EqualAreaProj, EqualAngleProj
@@ -15,16 +13,18 @@ class StereoGrid:
     """
     The class to store values with associated uniformly positions.
 
-    ``StereoGrid`` is used to calculate continous functions on sphere e.g. density distribution.
+    ``StereoGrid`` is used to calculate continous functions on sphere e.g. density
+    distribution.
 
     Keyword Args:
-        kind (str): Equal area ("equal-area", "schmidt" or "earea") or equal angle ("equal-angle",
-          "wulff" or "eangle") projection. Default is "equal-area"
+        kind (str): Equal area ("equal-area", "schmidt" or "earea") or equal angle
+            ("equal-angle", "wulff" or "eangle") projection. Default is "equal-area"
         hemisphere (str): "lower" or "upper". Default is "lower"
-        overlay_position (tuple or Pair): Position of overlay X, Y, Z given by Pair. X is direction
-          of linear element, Z is normal to planar. Default is (0, 0, 0, 0)
-        rotate_data (bool): Whether plotted data should be rotated together with overlay.
-          Default False
+        overlay_position (tuple or Pair): Position of overlay X, Y, Z given by Pair.
+            X is direction of linear element, Z is normal to planar.
+            Default is (0, 0, 0, 0)
+        rotate_data (bool): Whether data should be rotated together with overlay.
+            Default False
         minor_ticks (None or float): Default None
         major_ticks (None or float): Default None
         overlay (bool): Whether to show overlay. Default is True
@@ -34,7 +34,8 @@ class StereoGrid:
         grid_type (str): Type of contouring grid "gss" or "sfs". Default "gss"
         grid_n (int): Number of counting points in grid. Default 3000
 
-    Note: Euclidean norms are used as weights. Normalize data if you dont want to use weigths.
+    Note: Euclidean norms are used as weights. Normalize data if you dont want to use
+    weigths.
 
     """
 
@@ -107,10 +108,11 @@ class StereoGrid:
             # k = estimate_k(features)
             # sigma = np.sqrt(2 * n / (k - 2))
             # Totally empirical as estimate_k is problematic
-            sigma = np.sqrt(2 * n / (np.log(n) - 2)) / 3
-            k = 2 * (1.0 + n / sigma**2)
-        else:
-            k = 2 * (1.0 + n / sigma**2)
+            if n < 10:
+                sigma = 3
+            else:
+                sigma = np.sqrt(2 * n / (np.log(n) - 2)) / 3
+        k = 2 * (1.0 + n / sigma**2)
         # method = kwargs.get("method", "exp_kamb")
         trim = kwargs.get("trimzero", True)
         sigmanorm = kwargs.get("sigmanorm", True)
@@ -204,8 +206,7 @@ class StereoGrid:
         dcgrid = np.asarray(self.grid).T
         X, Y = self.proj.project_data(*dcgrid, clip_inside=False)
         cf = ax.tricontourf(X, Y, self.values, **parsed)
-        for collection in cf.collections:
-            collection.set_clip_path(primitive)
+        cf.set_clip_path(primitive)
         ax.set_xlim(-1.05, 1.05)
         ax.set_ylim(-1.05, 1.05)
         if colorbar:
@@ -247,15 +248,14 @@ class StereoGrid:
             radius=1,
             edgecolor="black",
             fill=False,
-            clip_box="None",
+            clip_box=None,
             label="_nolegend_",
         )
         ax.add_patch(primitive)
         dcgrid = np.asarray(self.grid).T
         X, Y = self.proj.project_data(*dcgrid, clip_inside=False)
         cf = ax.tricontour(X, Y, self.values, **parsed)
-        for collection in cf.collections:
-            collection.set_clip_path(primitive)
+        cf.set_clip_path(primitive)
         if colorbar:
             fig.colorbar(cf, ax=ax, shrink=0.6)
         plt.show()
@@ -279,7 +279,7 @@ class StereoGrid:
             radius=1,
             edgecolor="black",
             fill=False,
-            clip_box="None",
+            clip_box=None,
             label="_nolegend_",
         )
         ax.add_patch(primitive)
