@@ -10,7 +10,6 @@ from apsg.config import apsg_conf
 from apsg.math._vector import Vector3
 from apsg.feature._geodata import Lineation, Foliation, Pair, Fault, Cone
 from apsg.feature._container import (
-    FeatureSet,
     Vector3Set,
     LineationSet,
     FoliationSet,
@@ -19,8 +18,6 @@ from apsg.feature._container import (
 )
 from apsg.feature import feature_from_json
 from apsg.plotting._stereogrid import StereoGrid
-from apsg.feature._tensor3 import OrientationTensor3
-from apsg.plotting._projection import EqualAreaProj, EqualAngleProj
 from apsg.plotting._plot_artists import StereoNetArtistFactory
 
 __all__ = ["StereoNet"]
@@ -32,14 +29,17 @@ class StereoNet:
 
     Keyword Args:
         title (str): figure title. Default None.
+        title_kws (dict): dictionary of keyword arguments passed to matplotlib suptitle
+            method.
         tight_layout (bool): Matplotlib figure tight_layout. Default False
-        kind (str): Equal area ("equal-area", "schmidt" or "earea") or equal angle ("equal-angle",
-          "wulff" or "eangle") projection. Default is "equal-area"
+        kind (str): Equal area ("equal-area", "schmidt" or "earea") or equal angle
+            ("equal-angle", "wulff" or "eangle") projection. Default is "equal-area"
         hemisphere (str): "lower" or "upper". Default is "lower"
-        overlay_position (tuple or Pair): Position of overlay X, Y, Z given by Pair. X is direction
-          of linear element, Z is normal to planar. Default is (0, 0, 0, 0)
-        rotate_data (bool): Whether plotted data should be rotated together with overlay.
-          Default False
+        overlay_position (tuple or Pair): Position of overlay X, Y, Z given by Pair.
+            X is direction of linear element, Z is normal to planar.
+            Default is (0, 0, 0, 0)
+        rotate_data (bool): Whether data should be rotated together with overlay.
+            Default False
         minor_ticks (None or float): Default None
         major_ticks (None or float): Default None
         overlay (bool): Whether to show overlay. Default is True
@@ -135,7 +135,6 @@ class StereoNet:
             radius=1,
             edgecolor="black",
             fill=False,
-            clip_box="None",
             label="_nolegend_",
         )
         self.ax.add_patch(self.primitive)
@@ -212,7 +211,7 @@ class StereoNet:
                 numpoints=1,
             )
         if self._kwargs["title"] is not None:
-            self.fig.suptitle(self._kwargs["title"])
+            self.fig.suptitle(self._kwargs["title"], **self._kwargs["title_kws"])
         if self._kwargs["tight_layout"]:
             self.fig.tight_layout()
 
@@ -226,11 +225,21 @@ class StereoNet:
         self.fig = fig
         self._render()
 
+    def format_coord(self, x, y):
+        """Format stereonet coordinates"""
+        if x is not None and y is not None:
+            if (x**2 + y**2) <= 1:
+                lcoord = Lineation(*self.proj.inverse_data(x, y))
+                fcoord = Foliation(*self.proj.inverse_data(x, y))
+                return f"{lcoord} {fcoord}"
+        return ""
+
     def show(self):
         """Show stereonet"""
         plt.close(0)  # close previously rendered figure
         self.init_figure()
         self._render()
+        self.ax.format_coord = self.format_coord
         plt.show()
 
     def savefig(self, filename="stereonet.png", **kwargs):
@@ -253,7 +262,24 @@ class StereoNet:
     ########################################
 
     def line(self, *args, **kwargs):
-        """Plot linear feature(s) as point(s)"""
+        """
+        Plot linear feature(s) as point(s)
+
+        Args:
+            Vector3 or Vector3Set like feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            mec (color): Set the edge color. Default None
+            mfc (color): Set the face color. Default None
+            mew (float): Set the marker edge width. Default 1
+            ms (float): Set the marker size. Default 6
+            marker (str): Marker style string. Default "o"
+            ls (str): Line style string (only for multiple features).
+                Default None
+
+        """
         try:
             artist = StereoNetArtistFactory.create_point(*args, **kwargs)
             self._artists.append(artist)
@@ -261,7 +287,24 @@ class StereoNet:
             print(err)
 
     def pole(self, *args, **kwargs):
-        """Plot pole of planar feature(s) as point(s)"""
+        """
+        Plot pole of planar feature(s) as point(s)
+
+        Args:
+            Foliation or FoliationSet feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            mec (color): Set the edge color. Default None
+            mfc (color): Set the face color. Default None
+            mew (float): Set the marker edge width. Default 1
+            ms (float): Set the marker size. Default 6
+            marker (str): Marker style string. Default "o"
+            ls (str): Line style string (only for multiple features).
+                Default None
+
+        """
         try:
             artist = StereoNetArtistFactory.create_pole(*args, **kwargs)
             self._artists.append(artist)
@@ -269,8 +312,26 @@ class StereoNet:
             print(err)
 
     def vector(self, *args, **kwargs):
-        """Plot vector feature(s) as point(s),
-        filled on lower and open on upper hemisphere."""
+        """
+        Plot vector feature(s) as point(s)
+
+        Note: Markers are filled on lower and open on upper hemisphere.
+
+        Args:
+            Vector3 or Vector3Set like feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            mec (color): Set the edge color. Default None
+            mfc (color): Set the face color. Default None
+            mew (float): Set the marker edge width. Default 1
+            ms (float): Set the marker size. Default 6
+            marker (str): Marker style string. Default "o"
+            ls (str): Line style string (only for multiple features).
+                Default None
+
+        """
         try:
             artist = StereoNetArtistFactory.create_vector(*args, **kwargs)
             self._artists.append(artist)
@@ -278,7 +339,26 @@ class StereoNet:
             print(err)
 
     def scatter(self, *args, **kwargs):
-        """Plot vector-like feature(s) as point(s) using scatter"""
+        """
+        Plot vector-like feature(s) as point(s)
+
+        Note: This method is using scatter plot to allow variable colors
+            or sizes of points
+
+        Args:
+            Vector3 or Vector3Set like feature(s)
+
+        Keyword Args:
+            s (list or array):
+            c (list or array)
+            alpha (scalar): Set the alpha value. Default None
+            linewidths (float): The linewidth of the marker edges. Default 1.5
+            marker (str): Marker style string. Default "o"
+            cmap (str): Mtplotlib colormap. Default None
+            legend (bool): Whether to show legend. Default False
+            num (int): NUmber of legend items. Default "auto"
+
+        """
         try:
             artist = StereoNetArtistFactory.create_scatter(*args, **kwargs)
             self._artists.append(artist)
@@ -286,15 +366,47 @@ class StereoNet:
             print(err)
 
     def great_circle(self, *args, **kwargs):
-        """Plot planar feature(s) as great circle(s)"""
+        """
+        Plot planar feature(s) as great circle(s)
+
+        Note: ``great_circle`` has also alias ``gc``
+
+        Args:
+            Foliation or FoliationSet feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+
+        """
         try:
             artist = StereoNetArtistFactory.create_great_circle(*args, **kwargs)
             self._artists.append(artist)
         except TypeError as err:
             print(err)
 
+    gc = great_circle
+
     def arc(self, *args, **kwargs):
-        """Plot arc bewtween two vectors along great circle(s)"""
+        """
+        Plot arc bewtween vectors along great circle(s)
+
+        Note: You should pass several features in connection order
+
+        Args:
+            Vector3 or Vector3Set like feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+
+        """
         try:
             artist = StereoNetArtistFactory.create_arc(*args, **kwargs)
             self._artists.append(artist)
@@ -302,7 +414,21 @@ class StereoNet:
             print(err)
 
     def cone(self, *args, **kwargs):
-        """Plot small circle(s) with given angle(s)"""
+        """"""
+        """
+        Plot cone(s) as small circle(s) with given apical angle(s)
+
+        Args:
+            Cone or ConeSet feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+
+        """
         try:
             artist = StereoNetArtistFactory.create_cone(*args, **kwargs)
             self._artists.append(artist)
@@ -310,7 +436,21 @@ class StereoNet:
             print(err)
 
     def pair(self, *args, **kwargs):
-        """Plot pair feature(s) as great circle and point"""
+        """
+        Plot pair feature(s) as great circle and point
+
+        Args:
+            Pair or PairSet feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+            line_marker (str): Marker style string for point. Default "o"
+
+        """
         try:
             artist = StereoNetArtistFactory.create_pair(*args, **kwargs)
             self._artists.append(artist)
@@ -318,7 +458,22 @@ class StereoNet:
             print(err)
 
     def fault(self, *args, **kwargs):
-        """Plot fault feature(s) as great circle and point"""
+        """
+        Plot fault feature(s) as great circle and arrow
+
+        Note: Arrow is styled according to default arrow config
+
+        Args:
+            Fault or FaultSet feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+
+        """
         try:
             artist = StereoNetArtistFactory.create_fault(*args, **kwargs)
             self._artists.append(artist)
@@ -326,7 +481,22 @@ class StereoNet:
             print(err)
 
     def hoeppner(self, *args, **kwargs):
-        """Plot a fault-and-striae as in tangent lineation plot - Hoeppner plot."""
+        """
+        Plot fault feature(s) on Hoeppner (tangent lineation) plot
+
+        Note: Arrow is styled according to default arrow config
+
+        Args:
+            Fault or FaultSet feature(s)
+
+        Keyword Args:
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color of the point. Default None
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+
+        """
         try:
             artist = StereoNetArtistFactory.create_hoeppner(*args, **kwargs)
             self._artists.append(artist)
@@ -334,17 +504,62 @@ class StereoNet:
             print(err)
 
     def arrow(self, *args, **kwargs):
-        """Plot arrows at position of first argument
-        and oriented in direction of second"""
+        """
+        Plot arrow at position of first argument
+        and oriented in direction of second
+
+        Note: You should pass two features
+
+        Args:
+            Vector3 or Vector3Set like feature(s)
+
+        Keyword Args:
+            color (color): Set the color of the arrow. Default None
+            width (int): Width of arrow. Default 2
+            headwidth (int): Width of arrow head. Default 5
+            pivot (str): Arrow pivot. Default "mid"
+            units (str): Arrow size units. Default "dots"
+
+        """
         try:
             artist = StereoNetArtistFactory.create_arrow(*args, **kwargs)
             self._artists.append(artist)
         except TypeError as err:
             print(err)
 
+    def tensor(self, *args, **kwargs):
+        """
+        Plot principal planes or principal directions of tensor
+
+        Args:
+            OrientationTensor3 like feature(s)
+
+        Keyword Args:
+            planes (bool): When True, plot principal planes, otherwise principal
+                directions. Default True
+            alpha (scalar): Set the alpha value. Default None
+            color (color): Set the color. Default is red, green, blue for s1, s2, s3
+            ls (str): Line style string (only for multiple features).
+                Default "-"
+            lw (float): Set line width. Default 1.5
+            mew (float): Set the marker edge width. Default 1
+            ms (float): Set the marker size. Default 9
+            marker (str): Marker style string. Default "o"
+
+        """
+        try:
+            artist = StereoNetArtistFactory.create_tensor(*args, **kwargs)
+            self._artists.append(artist)
+        except TypeError as err:
+            print(err)
+
     def contour(self, *args, **kwargs):
         """
-        Plot filled contours using modified Kamb contouring technique with exponential smoothing
+        Plot filled contours using modified Kamb contouring technique with exponential
+        smoothing.
+
+        Args:
+            Vector3Set like feature
 
         Keyword Args:
             levels (int or list): number or values of contours. Default 6
@@ -353,13 +568,14 @@ class StereoNet:
             alpha (float): transparency. Default None
             antialiased (bool): Default True
             sigma (float): If None it is automatically calculated
-            sigmanorm (bool): If True scaled counts are normalized by sigma. Default True
+            sigmanorm (bool): If True scaled counts are normalized by sigma.
+                Default True
             trimzero (bool): Remove values equal to 0. Default True
             clines (bool): Show contour lines instead filled contours. Default False
             linewidths (float): contour lines width
             linestyles (str): contour lines style
             show_data (bool): Show data as points. Default False
-            data_kwargs (dict): arguments passed to point factory
+            data_kws (dict): arguments passed to point factory when `show_data` True
         """
         try:
             artist = StereoNetArtistFactory.create_contour(*args, **kwargs)
@@ -481,18 +697,26 @@ class StereoNet:
         legend = kwargs.pop("legend")
         num = kwargs.pop("num")
         x_lower, y_lower = self.proj.project_data(*np.vstack(args).T)
-        mask_lower = ~np.isnan(x_lower)
-        x_upper, y_upper, mask_upper = self.proj.project_data(*(-np.vstack(args).T))
-        mask_upper = ~np.isnan(x_upper)
+        # mask_lower = ~np.isnan(x_lower)
+        x_upper, y_upper = self.proj.project_data(*(-np.vstack(args).T))
+        # mask_upper = ~np.isnan(x_upper)
+        # x_lower, y_lower, x_upper, y_upper = self.proj.project_data_antipodal(
+        #    *np.vstack(args).T
+        # )
         prop = "sizes"
         if kwargs["s"] is not None:
             s = np.atleast_1d(kwargs["s"])
-            kwargs["s"] = np.hstack((s[mask_lower], s[mask_upper]))
+            # kwargs["s"] = np.hstack((s[mask_lower], s[mask_upper]))
+            kwargs["s"] = np.hstack((s, s))
         if kwargs["c"] is not None:
             c = np.atleast_1d(kwargs["c"])
-            kwargs["c"] = np.hstack((c[mask_lower], c[mask_upper]))
+            # kwargs["c"] = np.hstack((c[mask_lower], c[mask_upper]))
+            kwargs["c"] = np.hstack((c, c))
             prop = "colors"
         sc = self.ax.scatter(
+            # np.hstack((x_lower[mask_lower], x_upper[mask_upper])),
+            # np.hstack((y_lower[mask_lower], y_upper[mask_upper])),
+            # **kwargs,
             np.hstack((x_lower, x_upper)),
             np.hstack((y_lower, y_upper)),
             **kwargs,
@@ -584,7 +808,7 @@ class StereoNet:
 
     def _fault(self, *args, **kwargs):
         h = self._great_circle(*[arg.fol for arg in args], **kwargs)
-        quiver_kwargs = apsg_conf["stereonet_default_quiver_kwargs"]
+        quiver_kwargs = apsg_conf["stereonet_default_arrow_kwargs"]
         quiver_kwargs["pivot"] = "tail"
         quiver_kwargs["color"] = h[0].get_color()
         for arg in args:
@@ -592,7 +816,7 @@ class StereoNet:
 
     def _hoeppner(self, *args, **kwargs):
         h = self._line(*[arg.fol for arg in args], **kwargs)
-        quiver_kwargs = apsg_conf["stereonet_default_quiver_kwargs"]
+        quiver_kwargs = apsg_conf["stereonet_default_arrow_kwargs"]
         quiver_kwargs["color"] = h[0].get_color()
         for arg in args:
             self._arrow(arg.fol, arg.lin, sense=arg.sense, **quiver_kwargs)
@@ -632,6 +856,30 @@ class StereoNet:
         h = self.ax.quiver(x, y, u, v, **kwargs)
         h.set_clip_path(self.primitive)
 
+    def _tensor(self, *args, **kwargs):
+        if kwargs.get("planes"):
+            selkw = {
+                key: kwargs[key]
+                for key in kwargs.keys() & {"alpha", "ls", "lw", "label"}
+            }
+            fols = args[0].eigenfols()
+            if kwargs["color"] is None:
+                del kwargs["color"]
+            self._great_circle(fols[0], color=kwargs.get("color", "red"), **selkw)
+            self._great_circle(fols[1], color=kwargs.get("color", "green"), **selkw)
+            self._great_circle(fols[2], color=kwargs.get("color", "blue"), **selkw)
+        else:
+            selkw = {
+                key: kwargs[key]
+                for key in kwargs.keys() & {"alpha", "marker", "mew", "ms", "label"}
+            }
+            lins = args[0].eigenfols()
+            if kwargs["color"] is None:
+                del kwargs["color"]
+            self._line(lins[0], color=kwargs.get("color", "red"), **selkw)
+            self._line(lins[1], color=kwargs.get("color", "green"), **selkw)
+            self._line(lins[2], color=kwargs.get("color", "blue"), **selkw)
+
     def _contour(self, *args, **kwargs):
         sigma = kwargs.pop("sigma")
         trimzero = kwargs.pop("trimzero")
@@ -642,7 +890,7 @@ class StereoNet:
         linewidths = kwargs.pop("linewidths")
         linestyles = kwargs.pop("linestyles")
         show_data = kwargs.pop("show_data")
-        data_kwargs = kwargs.pop("data_kwargs")
+        data_kws = kwargs.pop("data_kws")
         if not self.grid.calculated:
             if len(args) > 0:
                 self.grid.calculate_density(
@@ -653,18 +901,16 @@ class StereoNet:
         dcgrid = np.asarray(self.grid.grid).T
         X, Y = self.proj.project_data(*dcgrid, clip_inside=False)
         cf = self.ax.tricontourf(X, Y, self.grid.values, **kwargs)
-        for collection in cf.collections:
-            collection.set_clip_path(self.primitive)
+        cf.set_clip_path(self.primitive)
         if clines:
             kwargs["cmap"] = None
             kwargs["colors"] = "k"
             kwargs["linewidths"] = linewidths
             kwargs["linestyles"] = linestyles
             cl = self.ax.tricontour(X, Y, self.grid.values, **kwargs)
-            for collection in cl.collections:
-                collection.set_clip_path(self.primitive)
+            cl.set_clip_path(self.primitive)
         if show_data:
-            artist = StereoNetArtistFactory.create_point(*args[0], **data_kwargs)
+            artist = StereoNetArtistFactory.create_point(*args[0], **data_kws)
             self._line(*artist.args, **artist.kwargs)
         if colorbar:
             self.fig.colorbar(cf, ax=self.ax, shrink=0.5, anchor=(0.0, 0.3))
@@ -692,49 +938,51 @@ def quicknet(*args, **kwargs):
         filename (str): filename for figure. Default `stereonet.png`
         savefig_kwargs (dict): dict passed to ``plt.savefig``
         fol_as_pole (bool): True to plot planar features as poles,
-            False for plotting as great circle. Default `True`
+            False for plotting as great circle. Default `False`
+        Additional kwargs are passed to StereoNet method
 
     Example:
         >>> l = linset.random_fisher(position=lin(120, 50))
         >>> f = folset.random_fisher(position=lin(300, 40))
-        >>> quicknet(f, l, fol_as_pole=False)
+        >>> quicknet(f, l)
     """
     savefig = kwargs.get("savefig", False)
     filename = kwargs.get("filename", "stereonet.png")
     savefig_kwargs = kwargs.get("savefig_kwargs", {})
-    fol_as_pole = kwargs.get("fol_as_pole", True)
+    fol_as_pole = kwargs.get("fol_as_pole", False)
+    kwargs["label"] = kwargs.get("label", "_nolegend_")
     s = StereoNet(**kwargs)
     for arg in args:
         if isinstance(arg, Vector3):
             if isinstance(arg, Foliation):
                 if fol_as_pole:
-                    s.pole(arg)
+                    s.pole(arg, **kwargs)
                 else:
-                    s.great_circle(arg)
+                    s.great_circle(arg, **kwargs)
             elif isinstance(arg, Lineation):
-                s.line(arg)
+                s.line(arg, **kwargs)
             else:
-                s.vector(arg)
-        elif isinstance(arg, Pair):
-            s.pair(arg)
+                s.vector(arg, **kwargs)
         elif isinstance(arg, Fault):
-            s.fault(arg)
+            s.fault(arg, **kwargs)
+        elif isinstance(arg, Pair):
+            s.pair(arg, **kwargs)
         elif isinstance(arg, Cone):
-            s.cone(arg)
+            s.cone(arg, **kwargs)
         elif isinstance(arg, Vector3Set):
             if isinstance(arg, FoliationSet):
                 if fol_as_pole:
-                    s.pole(arg)
+                    s.pole(arg, **kwargs)
                 else:
-                    s.great_circle(arg)
+                    s.great_circle(arg, **kwargs)
             elif isinstance(arg, LineationSet):
-                s.line(arg)
+                s.line(arg, **kwargs)
             else:
-                s.vector(arg)
-        elif isinstance(arg, PairSet):
-            s.pair(arg)
+                s.vector(arg, **kwargs)
         elif isinstance(arg, FaultSet):
-            s.fault(arg)
+            s.fault(arg, **kwargs)
+        elif isinstance(arg, PairSet):
+            s.pair(arg, **kwargs)
         else:
             print(f"{type(arg)} not supported.")
     if savefig:
